@@ -35,44 +35,7 @@
 #include <unistd.h>
 
 #include <pmix.h>
-
-typedef struct {
-    pthread_mutex_t mutex;
-    pthread_cond_t cond;
-    volatile bool active;
-    pmix_status_t status;
-} mylock_t;
-
-#define DEBUG_CONSTRUCT_LOCK(l)                \
-    do {                                       \
-        pthread_mutex_init(&(l)->mutex, NULL); \
-        pthread_cond_init(&(l)->cond, NULL);   \
-        (l)->active = true;                    \
-        (l)->status = PMIX_SUCCESS;            \
-    } while (0)
-
-#define DEBUG_DESTRUCT_LOCK(l)              \
-    do {                                    \
-        pthread_mutex_destroy(&(l)->mutex); \
-        pthread_cond_destroy(&(l)->cond);   \
-    } while (0)
-
-#define DEBUG_WAIT_THREAD(lck)                              \
-    do {                                                    \
-        pthread_mutex_lock(&(lck)->mutex);                  \
-        while ((lck)->active) {                             \
-            pthread_cond_wait(&(lck)->cond, &(lck)->mutex); \
-        }                                                   \
-        pthread_mutex_unlock(&(lck)->mutex);                \
-    } while (0)
-
-#define DEBUG_WAKEUP_THREAD(lck)              \
-    do {                                      \
-        pthread_mutex_lock(&(lck)->mutex);    \
-        (lck)->active = false;                \
-        pthread_cond_broadcast(&(lck)->cond); \
-        pthread_mutex_unlock(&(lck)->mutex);  \
-    } while (0)
+#include "examples.h"
 
 static pmix_proc_t myproc;
 static mylock_t invitedlock;
@@ -82,6 +45,9 @@ static void notification_fn(size_t evhdlr_registration_id, pmix_status_t status,
                             pmix_info_t results[], size_t nresults,
                             pmix_event_notification_cbfunc_fn_t cbfunc, void *cbdata)
 {
+    EXAMPLES_HIDE_UNUSED_PARAMS(evhdlr_registration_id, source,
+                                info, ninfo, results, nresults);
+
     fprintf(stderr, "Client %s:%d NOTIFIED with status %d\n", myproc.nspace, myproc.rank, status);
     if (NULL != cbfunc) {
         cbfunc(PMIX_EVENT_ACTION_COMPLETE, NULL, 0, NULL, NULL, cbdata);
@@ -98,6 +64,8 @@ static void op_callbk(pmix_status_t status, void *cbdata)
 
 static void errhandler_reg_callbk(pmix_status_t status, size_t errhandler_ref, void *cbdata)
 {
+    EXAMPLES_HIDE_UNUSED_PARAMS(errhandler_ref);
+
     mylock_t *lock = (mylock_t *) cbdata;
 
     lock->status = status;
@@ -107,6 +75,8 @@ static void errhandler_reg_callbk(pmix_status_t status, size_t errhandler_ref, v
 static void grpcomplete(pmix_status_t status, pmix_info_t *info, size_t ninfo, void *cbdata,
                         pmix_release_cbfunc_t release_fn, void *release_cbdata)
 {
+    EXAMPLES_HIDE_UNUSED_PARAMS(status, info, ninfo, cbdata, release_fn, release_cbdata);
+
     fprintf(stderr, "%s:%d GRPCOMPLETE\n", myproc.nspace, myproc.rank);
     DEBUG_WAKEUP_THREAD(&invitedlock);
 }
@@ -119,6 +89,8 @@ static void invitefn(size_t evhdlr_registration_id, pmix_status_t status, const
     char *grp = NULL;
     pmix_status_t rc;
 
+    EXAMPLES_HIDE_UNUSED_PARAMS(evhdlr_registration_id, results, nresults);
+
     /* if I am the leader, I can ignore this event */
     if (PMIX_CHECK_PROCID(source, &myproc)) {
         fprintf(stderr, "%s:%d INVITED, BUT LEADER\n", myproc.nspace, myproc.rank);
@@ -163,6 +135,8 @@ int main(int argc, char **argv)
     pmix_info_t *results;
     size_t nresults;
 
+    EXAMPLES_HIDE_UNUSED_PARAMS(argc, argv);
+
     /* init us */
     if (PMIX_SUCCESS != (rc = PMIx_Init(&myproc, NULL, 0))) {
         fprintf(stderr, "Client ns %s rank %d: PMIx_Init failed: %s\n", myproc.nspace, myproc.rank,
