@@ -25,9 +25,11 @@
  *
  */
 
+#include "examples.h"
 #include "src/include/pmix_config.h"
 #include "../include/pmix.h"
 
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <time.h>
@@ -49,6 +51,8 @@ int main(int argc, char **argv)
     pmix_rank_t *locals = NULL;
     uint8_t j;
 
+    EXAMPLES_HIDE_UNUSED_PARAMS(argc, argv);
+
     /* init us */
     if (PMIX_SUCCESS != (rc = PMIx_Init(&myproc, NULL, 0))) {
         fprintf(stderr, "Client ns %s rank %d: PMIx_Init failed: %d\n", myproc.nspace, myproc.rank,
