@@ -49,6 +49,8 @@
 #include "src/util/pmix_environ.h"
 #include "src/util/printf.h"
 
+#include "examples.h"
+
 static pmix_status_t connected(const pmix_proc_t *proc, void *server_object,
                                pmix_op_cbfunc_t cbfunc, void *cbdata);
 static pmix_status_t finalized(const pmix_proc_t *proc, void *server_object,
@@ -173,6 +175,7 @@ static void errhandler_reg_callbk(pmix_status_t status, size_t errhandler_ref, v
 static void opcbfunc(pmix_status_t status, void *cbdata)
 {
     myxfer_t *x = (myxfer_t *) cbdata;
+    EXAMPLES_HIDE_UNUSED_PARAMS(status);
 
     /* release the caller, if necessary */
     if (NULL != x->cbfunc) {
@@ -460,17 +463,22 @@ static void errhandler(size_t evhdlr_registration_id, pmix_status_t status,
                        pmix_info_t results[], size_t nresults,
                        pmix_event_notification_cbfunc_fn_t cbfunc, void *cbdata)
 {
+    EXAMPLES_HIDE_UNUSED_PARAMS(evhdlr_registration_id, source,
+                                info, ninfo, results, nresults,
+                                cbfunc, cbdata);
     pmix_output(0, "SERVER: ERRHANDLER CALLED WITH STATUS %d", status);
 }
 
 static void errhandler_reg_callbk(pmix_status_t status, size_t errhandler_ref, void *cbdata)
 {
+    EXAMPLES_HIDE_UNUSED_PARAMS(status, errhandler_ref, cbdata);
     return;
 }
 
 static pmix_status_t connected(const pmix_proc_t *proc, void *server_object,
                                pmix_op_cbfunc_t cbfunc, void *cbdata)
 {
+    EXAMPLES_HIDE_UNUSED_PARAMS(proc, server_object);
     if (NULL != cbfunc) {
         cbfunc(PMIX_SUCCESS, cbdata);
     }
@@ -479,6 +487,7 @@ static pmix_status_t connected(const pmix_proc_t *proc, void *server_object,
 static pmix_status_t finalized(const pmix_proc_t *proc, void *server_object,
                                pmix_op_cbfunc_t cbfunc, void *cbdata)
 {
+    EXAMPLES_HIDE_UNUSED_PARAMS(server_object);
     pmix_output(0, "SERVER: FINALIZED %s:%d", proc->nspace, proc->rank);
     --wakeup;
     /* ensure we call the cbfunc so the proc can exit! */
@@ -505,6 +514,7 @@ static pmix_status_t abort_fn(const pmix_proc_t *proc, void *server_object, int
 {
     pmix_status_t rc;
     myxfer_t *x;
+    EXAMPLES_HIDE_UNUSED_PARAMS(server_object, msg, nprocs);
 
     if (NULL != procs) {
         pmix_output(0, "SERVER: ABORT on %s:%d", procs[0].nspace, procs[0].rank);
@@ -544,6 +554,8 @@ static pmix_status_t fencenb_fn(const pmix_proc_t procs[], size_t nprocs, const
                                 size_t ninfo, char *data, size_t ndata, pmix_modex_cbfunc_t cbfunc,
                                 void *cbdata)
 {
+    EXAMPLES_HIDE_UNUSED_PARAMS(procs, nprocs, info, ninfo);
+
     pmix_output(0, "SERVER: FENCENB");
     /* pass the provided data back to each participating proc */
     if (NULL != cbfunc) {
@@ -555,6 +567,8 @@ static pmix_status_t fencenb_fn(const pmix_proc_t procs[], size_t nprocs, const
 static pmix_status_t dmodex_fn(const pmix_proc_t *proc, const pmix_info_t info[], size_t ninfo,
                                pmix_modex_cbfunc_t cbfunc, void *cbdata)
 {
+    EXAMPLES_HIDE_UNUSED_PARAMS(proc, info, ninfo);
+
     pmix_output(0, "SERVER: DMODEX");
 
     /* we don't have any data for remote procs as this
@@ -595,6 +609,7 @@ static pmix_status_t lookup_fn(const pmix_proc_t *proc, char **keys, const pmix_
     size_t i, n;
     pmix_pdata_t *pd = NULL;
     pmix_status_t ret = PMIX_ERR_NOT_FOUND;
+    EXAMPLES_HIDE_UNUSED_PARAMS(proc, info, ninfo);
 
     pmix_output(0, "SERVER: LOOKUP");
 
@@ -641,6 +656,7 @@ static pmix_status_t unpublish_fn(const pmix_proc_t *proc, char **keys, const pm
 {
     pmix_locdat_t *p, *p2;
     size_t n;
+    EXAMPLES_HIDE_UNUSED_PARAMS(proc, info, ninfo);
 
     pmix_output(0, "SERVER: UNPUBLISH");
 
@@ -662,6 +678,7 @@ static pmix_status_t unpublish_fn(const pmix_proc_t *proc, char **keys, const pm
 static void spcbfunc(pmix_status_t status, void *cbdata)
 {
     myxfer_t *x = (myxfer_t *) cbdata;
+    EXAMPLES_HIDE_UNUSED_PARAMS(status);
 
     if (NULL != x->spcbfunc) {
         x->spcbfunc(PMIX_SUCCESS, "DYNSPACE", x->cbdata);
@@ -673,6 +690,7 @@ static pmix_status_t spawn_fn(const pmix_proc_t *proc, const pmix_info_t job_inf
                               void *cbdata)
 {
     myxfer_t *x;
+    EXAMPLES_HIDE_UNUSED_PARAMS(proc, job_info, ninfo, apps, napps);
 
     pmix_output(0, "SERVER: SPAWN");
 
@@ -695,6 +713,7 @@ static pmix_status_t spawn_fn(const pmix_proc_t *proc, const pmix_info_t job_inf
 static pmix_status_t connect_fn(const pmix_proc_t procs[], size_t nprocs, const pmix_info_t info[],
                                 size_t ninfo, pmix_op_cbfunc_t cbfunc, void *cbdata)
 {
+    EXAMPLES_HIDE_UNUSED_PARAMS(procs, nprocs, info, ninfo);
     pmix_output(0, "SERVER: CONNECT");
 
     /* in practice, we would pass this request to the local
@@ -711,6 +730,7 @@ static pmix_status_t disconnect_fn(const pmix_proc_t procs[], size_t nprocs,
                                    const pmix_info_t info[], size_t ninfo, pmix_op_cbfunc_t cbfunc,
                                    void *cbdata)
 {
+    EXAMPLES_HIDE_UNUSED_PARAMS(procs, nprocs, info, ninfo);
     pmix_output(0, "SERVER: DISCONNECT");
 
     /* in practice, we would pass this request to the local
@@ -727,6 +747,7 @@ static pmix_status_t register_event_fn(pmix_status_t *codes, size_t ncodes,
                                        const pmix_info_t info[], size_t ninfo,
                                        pmix_op_cbfunc_t cbfunc, void *cbdata)
 {
+    EXAMPLES_HIDE_UNUSED_PARAMS(codes, ncodes, info, ninfo);
     if (NULL != cbfunc) {
         cbfunc(PMIX_SUCCESS, cbdata);
     }
@@ -736,6 +757,7 @@ static pmix_status_t register_event_fn(pmix_status_t *codes, size_t ncodes,
 static pmix_status_t deregister_events(pmix_status_t *codes, size_t ncodes, pmix_op_cbfunc_t cbfunc,
                                        void *cbdata)
 {
+    EXAMPLES_HIDE_UNUSED_PARAMS(codes, ncodes, cbfunc, cbdata);
     return PMIX_SUCCESS;
 }
 
@@ -743,6 +765,7 @@ static pmix_status_t notify_event(pmix_status_t code, const pmix_proc_t *source,
                                   pmix_data_range_t range, pmix_info_t info[], size_t ninfo,
                                   pmix_op_cbfunc_t cbfunc, void *cbdata)
 {
+    EXAMPLES_HIDE_UNUSED_PARAMS(code, source, range, info, ninfo, cbfunc, cbdata);
     return PMIX_SUCCESS;
 }
 
@@ -756,6 +779,7 @@ static pmix_status_t query_fn(pmix_proc_t *proct, pmix_query_t *queries, size_t
 {
     size_t n;
     pmix_info_t *info;
+    EXAMPLES_HIDE_UNUSED_PARAMS(proct);
 
     pmix_output(0, "SERVER: QUERY");
 
@@ -779,6 +803,7 @@ static void tool_connect_fn(pmix_info_t *info, size_t ninfo, pmix_tool_connectio
                             void *cbdata)
 {
     pmix_proc_t proc;
+    EXAMPLES_HIDE_UNUSED_PARAMS(info, ninfo);
 
     pmix_output(0, "SERVER: TOOL CONNECT");
 
@@ -796,6 +821,7 @@ static void log_fn(const pmix_proc_t *client, const pmix_info_t data[], size_t n
                    void *cbdata)
 {
     pmix_output(0, "SERVER: LOG");
+    EXAMPLES_HIDE_UNUSED_PARAMS(client, data, ndata, directives, ndirs);
 
     if (NULL != cbfunc) {
         cbfunc(PMIX_SUCCESS, cbdata);
@@ -808,6 +834,7 @@ static void wait_signal_callback(int fd, short event, void *arg)
     int status;
     pid_t pid;
     wait_tracker_t *t2;
+    EXAMPLES_HIDE_UNUSED_PARAMS(fd, event);
 
     if (SIGCHLD != pmix_event_get_signal(sig)) {
         return;
