@@ -38,6 +38,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
+ * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -129,7 +130,7 @@ PMIX_EXPORT pmix_status_t PMIx_Abort(int status, const char msg[],
  * the information locally until _PMIx_Commit_ is called. The provided scope
  * value is passed to the local PMIx server, which will distribute the data
  * as directed. */
-PMIX_EXPORT pmix_status_t PMIx_Put(pmix_scope_t scope, const pmix_key_t key, pmix_value_t *val);
+PMIX_EXPORT pmix_status_t PMIx_Put(pmix_scope_t scope, const char key[], pmix_value_t *val);
 
 
 /* Push all previously _PMIx_Put_ values to the local PMIx server.
@@ -208,7 +209,7 @@ PMIX_EXPORT pmix_status_t PMIx_Get(const pmix_proc_t *proc, const char key[],
  * be executed once the specified data has been _PMIx_Put_
  * by the identified process and retrieved by the local server. The info
  * array is used as described above for the blocking form of this call. */
-PMIX_EXPORT pmix_status_t PMIx_Get_nb(const pmix_proc_t *proc, const pmix_key_t key,
+PMIX_EXPORT pmix_status_t PMIx_Get_nb(const pmix_proc_t *proc, const char key[],
                                       const pmix_info_t info[], size_t ninfo,
                                       pmix_value_cbfunc_t cbfunc, void *cbdata);
 
@@ -1140,7 +1141,7 @@ PMIX_EXPORT const char* PMIx_Get_version(void);
  * proc. This is data that has only internal scope - it will
  * never be "pushed" externally */
 PMIX_EXPORT pmix_status_t PMIx_Store_internal(const pmix_proc_t *proc,
-                                              const pmix_key_t key, pmix_value_t *val);
+                                              const char key[], pmix_value_t *val);
 
 
 /******    DATA BUFFER PACK/UNPACK SUPPORT    ******/
@@ -1371,6 +1372,183 @@ PMIX_EXPORT pmix_status_t PMIx_Data_print(char **output, char *prefix,
 PMIX_EXPORT pmix_status_t PMIx_Data_copy_payload(pmix_data_buffer_t *dest,
                                                  pmix_data_buffer_t *src);
 
+/**
+ * Unload a buffer into a byte object
+ *
+ * The unload function provides the caller with a pointer to the data
+ * payload within the buffer and the size of that payload. This allows
+ * the user to directly access the payload.
+ *
+ * @note This is a destructive operation. While the payload is
+ * undisturbed, the function will clear the buffer's pointers to the
+ * payload. Thus, the buffer and the payload are completely separated,
+ * leaving the caller free to the buffer.
+ *
+ * @param buffer A pointer to the buffer whose payload is to be
+ * unloaded.
+ *
+ * @param payload The address of a pmix_byte_object_t into which
+ * the buffer is to be unloaded
+ *
+ * @retval PMIX_SUCCESS The request was succesfully completed.
+ *
+ * @retval PMIX_ERROR(s) An appropriate error code indicating the
+ * problem will be returned. This should be handled appropriately by
+ * the caller.
+ *
+ * @code
+ * pmix_data_buffer_t *buffer;
+ * pmix_byte_object_t payload;
+ *
+ * status_code = PMIx_Data_unload(buffer, &payload);
+ * @endcode
+ */
+PMIX_EXPORT pmix_status_t PMIx_Data_unload(pmix_data_buffer_t *buffer,
+                                           pmix_byte_object_t *payload);
+
+/**
+ * Load a data payload into a buffer.
+ *
+ * The load function allows the caller to replace the payload in a
+ * buffer with one provided by the caller. If a payload already exists
+ * in the buffer, the function will "free" the existing data to
+ * release it, and then replace the data payload with the one provided
+ * by the caller.
+ *
+ * @note The buffer must be allocated in advance - failing to do so
+ * will cause the load function to return an error code.
+ *
+ * @note The caller is responsible for pre-packing the provided
+ * payload - the load function cannot convert to network byte order
+ * any data contained in the provided payload.
+ *
+ * @note The "payload" object will be empty upon completion of
+ * this operation.
+ *
+ * @param buffer A pointer to the buffer into which the payload is to
+ * be loaded.
+ *
+ * @param payload A pointer to the pmix_byte_object_t .containing the
+ * desired payload
+ *
+ * @retval PMIX_SUCCESS The request was successfully completed
+ *
+ * @retval PMIX_ERROR(s) An appropriate error code indicating the
+ * problem will be returned. This should be handled appropriately by
+ * the caller.
+ *
+ * @code
+ * pmix_data_buffer_t *buffer;
+ * pmix_byte_object_t payload;
+ *
+ * PMIX_DATA_BUFFER_CREATE(buffer);
+ * status_code = PMIx_Data_load(buffer, &payload);
+ * @endcode
+ */
+PMIX_EXPORT pmix_status_t PMIx_Data_load(pmix_data_buffer_t *buffer,
+                                         pmix_byte_object_t *payload);
+
+/**
+* Embed a data payload into a buffer.
+*
+* The embed function is identical in operation to PMIx_Data_load
+* except that it does NOT "clear" the payload upon completion.
+*
+* @note The buffer must be allocated in advance - failing to do so
+* will cause the function to return an error code.
+*
+* @note The caller is responsible for pre-packing the provided
+* payload - the load function cannot convert to network byte order
+* any data contained in the provided payload.
+*
+* @note The "payload" object is unaltered by this operation.
+*
+* @param buffer A pointer to the buffer into which the payload is to
+* be loaded.
+*
+* @param payload A pointer to the pmix_byte_object_t .containing the
+* desired payload
+*
+* @retval PMIX_SUCCESS The request was successfully completed
+*
+* @retval PMIX_ERROR(s) An appropriate error code indicating the
+* problem will be returned. This should be handled appropriately by
+* the caller.
+*
+* @code
+* pmix_data_buffer_t *buffer;
+* pmix_byte_object_t payload;
+*
+* PMIX_DATA_BUFFER_CREATE(buffer);
+* status_code = PMIx_Data_embed(buffer, &payload);
+* @endcode
+*/
+PMIX_EXPORT pmix_status_t PMIx_Data_embed(pmix_data_buffer_t *buffer,
+                                          const pmix_byte_object_t *payload);
+
+/**
+* Compress data using loss-less compression algorithm.
+*
+* Compress the provided data block. Destination memory
+* will be allocated if successful operation is concluded. Caller
+* is responsible for release of the allocated region. The input
+* data block will remain unaltered.
+*
+* Note: the compress function will return "false" if the operation
+* would not result in a smaller data block.
+*
+* @param inbytes A pointer to the data to be compressed
+*
+* @param size Number of bytes in the input data region
+*
+* @param outbytes Address where a pointer to the compressed
+* data region is to be returned
+*
+* @param nbytes Address where the number of bytes in the
+* compressed data region is to be returned
+*
+* @retval true The input data was compressed.
+*
+* @retval false The input data was not compressed
+*
+*/
+PMIX_EXPORT bool PMIx_Data_compress(const uint8_t *inbytes,
+                                    size_t size,
+                                    uint8_t **outbytes,
+                                    size_t *nbytes);
+
+/**
+* Decompress data.
+*
+* Decompress the provided data block. Destination memory
+* will be allocated if successful operation is concluded. Caller
+* is responsible for release of the allocated region. The input
+* data block will remain unaltered.
+*
+* note: only data compressed using PMIx_Data_compress can
+* be input to this function
+*
+* @param inbytes A pointer to the data to be decompressed
+*
+* @param size Number of bytes in the input data region
+*
+* @param outbytes Address where a pointer to the decompressed
+* data region is to be returned
+*
+* @param nbytes Address where the number of bytes in the
+* decompressed data region is to be returned
+*
+* @retval true The input data was decompressed
+*
+* @retval false The input data was not decompressed
+*
+*/
+PMIX_EXPORT bool PMIx_Data_decompress(const uint8_t *inbytes,
+                                      size_t size,
+                                      uint8_t **outbytes,
+                                      size_t *nbytes);
+
+
 
 #if defined(c_plusplus) || defined(__cplusplus)
 }
