@@ -44,11 +44,10 @@
 #ifdef HAVE_SYS_TYPES_H
 #    include <sys/types.h>
 #endif
-#include PMIX_EVENT_HEADER
+#include <event.h>
 
 #include "src/class/pmix_list.h"
 #include "src/client/pmix_client_ops.h"
-#include "src/mca/ploc/ploc.h"
 #include "src/mca/pnet/base/base.h"
 #include "src/util/argv.h"
 #include "src/util/error.h"
@@ -87,6 +86,8 @@ static void frecv(struct pmix_peer_t *peer, pmix_ptl_hdr_t *hdr, pmix_buffer_t *
     pmix_status_t rc;
     int cnt;
 
+    PMIX_HIDE_UNUSED_PARAMS(hdr);
+
     pmix_output_verbose(2, pmix_globals.debug_output, "pmix:fabric recv from server with %d bytes",
                         (int) buf->bytes_used);
 
@@ -433,6 +434,8 @@ PMIX_EXPORT pmix_status_t PMIx_Fabric_deregister_nb(pmix_fabric_t *fabric, pmix_
 {
     pmix_status_t rc;
 
+    PMIX_HIDE_UNUSED_PARAMS(cbfunc, cbdata);
+
     PMIX_ACQUIRE_THREAD(&pmix_global_lock);
 
     /* if I am a scheduler server, then I should be able
