@@ -43,7 +43,7 @@
 #ifdef HAVE_SYS_TYPES_H
 #    include <sys/types.h>
 #endif
-#include PMIX_EVENT_HEADER
+#include <event.h>
 
 #include "src/class/pmix_list.h"
 #include "src/mca/bfrops/bfrops.h"
@@ -246,6 +246,7 @@ static void wait_cbfunc(struct pmix_peer_t *pr, pmix_ptl_hdr_t *hdr, pmix_buffer
     pmix_status_t rc;
 
     pmix_output_verbose(2, pmix_client_globals.fence_output, "pmix: fence_nb callback recvd");
+    PMIX_HIDE_UNUSED_PARAMS(pr, hdr);
 
     if (NULL == cb) {
         PMIX_ERROR_LOG(PMIX_ERR_BAD_PARAM);
