@@ -33,7 +33,7 @@
 #ifdef HAVE_SYS_TYPES_H
 #    include <sys/types.h>
 #endif
-#include PMIX_EVENT_HEADER
+#include <event.h>
 
 #include "include/pmix.h"
 #include "include/pmix_common.h"
@@ -136,7 +136,7 @@ typedef uint8_t pmix_cmd_t;
 #define PMIX_IOF_DEREG_CMD                29
 #define PMIX_FABRIC_REGISTER_CMD          30
 #define PMIX_FABRIC_UPDATE_CMD            31
-#define PMIX_FABRIC_COMPUTE_DISTANCES_CMD 32
+#define PMIX_COMPUTE_DEVICE_DISTANCES_CMD 32
 
 /* provide a "pretty-print" function for cmds */
 const char *pmix_command_string(pmix_cmd_t cmd);
@@ -203,7 +203,9 @@ typedef struct {
     bool nocopy;
     bool merge;
     bool local_output;
+    bool local_output_given;
     bool pattern;
+    bool raw;
 } pmix_iof_flags_t;
 
 /* objects used by servers for tracking active nspaces */
@@ -246,6 +248,20 @@ typedef struct {
 } pmix_nspace_caddy_t;
 PMIX_CLASS_DECLARATION(pmix_nspace_caddy_t);
 
+typedef struct {
+    pmix_list_item_t super;
+    pmix_namespace_t *ns;
+    pmix_list_t envars;
+} pmix_nspace_env_cache_t;
+PMIX_CLASS_DECLARATION(pmix_nspace_env_cache_t);
+
+typedef struct {
+    pmix_list_item_t super;
+    pmix_envar_t envar;
+} pmix_envar_list_item_t;
+PMIX_CLASS_DECLARATION(pmix_envar_list_item_t);
+
+
 typedef struct pmix_rank_info_t {
     pmix_list_item_t super;
     int peerid; // peer object index into the local clients array on the server
@@ -435,6 +451,7 @@ typedef struct {
         pmix_hdlr_reg_cbfunc_t hdlrregcbfn;
         pmix_op_cbfunc_t opcbfn;
         pmix_modex_cbfunc_t modexcbfunc;
+        pmix_info_cbfunc_t infocbfunc;
     } cbfunc;
     void *cbdata;
     size_t ref;
@@ -593,6 +610,7 @@ typedef struct {
     size_t output_limit;
     pmix_list_t nspaces;
     pmix_topology_t topology;
+    pmix_cpuset_t cpuset;
     bool external_topology;
     bool external_progress;
     pmix_iof_flags_t iof_flags;
@@ -659,6 +677,19 @@ static inline bool pmix_check_session_info(const char *key)
     return false;
 }
 
+#if PMIX_PICKY_COMPILERS
+#define PMIX_HIDE_UNUSED_PARAMS(...)                \
+    do {                                            \
+        int __x = 3;                                \
+        pmix_hide_unused_params(__x, __VA_ARGS__);  \
+    } while(0)
+
+PMIX_EXPORT void pmix_hide_unused_params(int x, ...);
+
+#else
+#define PMIX_HIDE_UNUSED_PARAMS(...)
+#endif
+
 END_C_DECLS
 
 #endif /* PMIX_GLOBALS_H */
