@@ -33,25 +33,23 @@
 
 static pmix_status_t init(void);
 static void finalize(void);
-static pmix_status_t register_type(const char *name, pmix_data_type_t type,
-                                   pmix_bfrop_pack_fn_t pack, pmix_bfrop_unpack_fn_t unpack,
-                                   pmix_bfrop_copy_fn_t copy, pmix_bfrop_print_fn_t print);
 static const char *data_type_string(pmix_data_type_t type);
 
-pmix_bfrops_module_t pmix_bfrops_pmix12_module = {.version = "v12",
-                                                  .init = init,
-                                                  .finalize = finalize,
-                                                  .pack = pmix12_bfrop_pack,
-                                                  .unpack = pmix12_bfrop_unpack,
-                                                  .copy = pmix12_bfrop_copy,
-                                                  .print = pmix12_bfrop_print,
-                                                  .copy_payload = pmix12_bfrop_copy_payload,
-                                                  .value_xfer = pmix12_bfrop_value_xfer,
-                                                  .value_load = pmix12_bfrop_value_load,
-                                                  .value_unload = pmix12_bfrop_value_unload,
-                                                  .value_cmp = pmix12_bfrop_value_cmp,
-                                                  .register_type = register_type,
-                                                  .data_type_string = data_type_string};
+pmix_bfrops_module_t pmix_bfrops_pmix12_module = {
+    .version = "v12",
+    .init = init,
+    .finalize = finalize,
+    .pack = pmix12_bfrop_pack,
+    .unpack = pmix12_bfrop_unpack,
+    .copy = pmix12_bfrop_copy,
+    .print = pmix12_bfrop_print,
+    .copy_payload = pmix12_bfrop_copy_payload,
+    .value_xfer = pmix12_bfrop_value_xfer,
+    .value_load = pmix12_bfrop_value_load,
+    .value_unload = pmix12_bfrop_value_unload,
+    .value_cmp = pmix12_bfrop_value_cmp,
+    .data_type_string = data_type_string
+};
 
 static pmix_status_t init(void)
 {
@@ -249,14 +247,6 @@ static void finalize(void)
     }
 }
 
-static pmix_status_t register_type(const char *name, pmix_data_type_t type,
-                                   pmix_bfrop_pack_fn_t pack, pmix_bfrop_unpack_fn_t unpack,
-                                   pmix_bfrop_copy_fn_t copy, pmix_bfrop_print_fn_t print)
-{
-    PMIX_REGISTER_TYPE(name, type, pack, unpack, copy, print, &mca_bfrops_v12_component.types);
-    return PMIX_SUCCESS;
-}
-
 static const char *data_type_string(pmix_data_type_t type)
 {
     pmix_bfrop_type_info_t *info;
