@@ -46,9 +46,8 @@ pmix_status_t pmix12_bfrop_print(char **output, char *prefix, void *src, pmix_da
 
     /* Lookup the print function for this type and call it */
 
-    if (NULL
-        == (info = (pmix_bfrop_type_info_t *)
-                pmix_pointer_array_get_item(&mca_bfrops_v12_component.types, type))) {
+    info = (pmix_bfrop_type_info_t *) pmix_pointer_array_get_item(&mca_bfrops_v12_component.types, type);
+    if (NULL == info) {
         return PMIX_ERR_UNKNOWN_DATA_TYPE;
     }
 
@@ -62,6 +61,8 @@ pmix_status_t pmix12_bfrop_print_bool(char **output, char *prefix, bool *src, pm
 {
     char *prefx;
 
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     /* deal with NULL prefix */
     if (NULL == prefix) {
         if (0 > asprintf(&prefx, " ")) {
@@ -98,6 +99,8 @@ pmix_status_t pmix12_bfrop_print_byte(char **output, char *prefix, uint8_t *src,
 {
     char *prefx;
 
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     /* deal with NULL prefix */
     if (NULL == prefix) {
         if (0 > asprintf(&prefx, " ")) {
@@ -133,6 +136,8 @@ pmix_status_t pmix12_bfrop_print_string(char **output, char *prefix, char *src,
 {
     char *prefx;
 
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     /* deal with NULL prefix */
     if (NULL == prefix) {
         if (0 > asprintf(&prefx, " ")) {
@@ -168,7 +173,9 @@ pmix_status_t pmix12_bfrop_print_size(char **output, char *prefix, size_t *src,
 {
     char *prefx;
 
-    /* deal with NULL prefix */
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
+   /* deal with NULL prefix */
     if (NULL == prefix) {
         if (0 > asprintf(&prefx, " ")) {
             return PMIX_ERR_NOMEM;
@@ -202,6 +209,8 @@ pmix_status_t pmix12_bfrop_print_pid(char **output, char *prefix, pid_t *src, pm
 {
     char *prefx;
 
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     /* deal with NULL prefix */
     if (NULL == prefix) {
         if (0 > asprintf(&prefx, " ")) {
@@ -235,6 +244,8 @@ pmix_status_t pmix12_bfrop_print_int(char **output, char *prefix, int *src, pmix
 {
     char *prefx;
 
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     /* deal with NULL prefix */
     if (NULL == prefix) {
         if (0 > asprintf(&prefx, " ")) {
@@ -269,6 +280,8 @@ pmix_status_t pmix12_bfrop_print_uint(char **output, char *prefix, uint *src, pm
 {
     char *prefx;
 
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     /* deal with NULL prefix */
     if (NULL == prefix) {
         if (0 > asprintf(&prefx, " ")) {
@@ -304,6 +317,8 @@ pmix_status_t pmix12_bfrop_print_uint8(char **output, char *prefix, uint8_t *src
 {
     char *prefx;
 
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     /* deal with NULL prefix */
     if (NULL == prefix) {
         if (0 > asprintf(&prefx, " ")) {
@@ -339,7 +354,9 @@ pmix_status_t pmix12_bfrop_print_uint16(char **output, char *prefix, uint16_t *s
 {
     char *prefx;
 
-    /* deal with NULL prefix */
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
+   /* deal with NULL prefix */
     if (NULL == prefix) {
         if (0 > asprintf(&prefx, " ")) {
             return PMIX_ERR_NOMEM;
@@ -374,6 +391,8 @@ pmix_status_t pmix12_bfrop_print_uint32(char **output, char *prefix, uint32_t *s
 {
     char *prefx;
 
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     /* deal with NULL prefix */
     if (NULL == prefix) {
         if (0 > asprintf(&prefx, " ")) {
@@ -409,6 +428,8 @@ pmix_status_t pmix12_bfrop_print_int8(char **output, char *prefix, int8_t *src,
 {
     char *prefx;
 
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     /* deal with NULL prefix */
     if (NULL == prefix) {
         if (0 > asprintf(&prefx, " ")) {
@@ -444,6 +465,8 @@ pmix_status_t pmix12_bfrop_print_int16(char **output, char *prefix, int16_t *src
 {
     char *prefx;
 
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     /* deal with NULL prefix */
     if (NULL == prefix) {
         if (0 > asprintf(&prefx, " ")) {
@@ -479,6 +502,8 @@ pmix_status_t pmix12_bfrop_print_int32(char **output, char *prefix, int32_t *src
 {
     char *prefx;
 
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     /* deal with NULL prefix */
     if (NULL == prefix) {
         if (0 > asprintf(&prefx, " ")) {
@@ -513,6 +538,8 @@ pmix_status_t pmix12_bfrop_print_uint64(char **output, char *prefix, uint64_t *s
 {
     char *prefx;
 
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     /* deal with NULL prefix */
     if (NULL == prefix) {
         if (0 > asprintf(&prefx, " ")) {
@@ -548,6 +575,8 @@ pmix_status_t pmix12_bfrop_print_int64(char **output, char *prefix, int64_t *src
 {
     char *prefx;
 
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     /* deal with NULL prefix */
     if (NULL == prefix) {
         if (0 > asprintf(&prefx, " ")) {
@@ -583,6 +612,8 @@ pmix_status_t pmix12_bfrop_print_float(char **output, char *prefix, float *src,
 {
     char *prefx;
 
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     /* deal with NULL prefix */
     if (NULL == prefix) {
         if (0 > asprintf(&prefx, " ")) {
@@ -618,6 +649,8 @@ pmix_status_t pmix12_bfrop_print_double(char **output, char *prefix, double *src
 {
     char *prefx;
 
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     /* deal with NULL prefix */
     if (NULL == prefix) {
         if (0 > asprintf(&prefx, " ")) {
@@ -654,7 +687,9 @@ pmix_status_t pmix12_bfrop_print_time(char **output, char *prefix, time_t *src,
     char *prefx;
     char *t;
 
-    /* deal with NULL prefix */
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
+   /* deal with NULL prefix */
     if (NULL == prefix) {
         if (0 > asprintf(&prefx, " ")) {
             return PMIX_ERR_NOMEM;
@@ -692,6 +727,8 @@ pmix_status_t pmix12_bfrop_print_timeval(char **output, char *prefix, struct tim
 {
     char *prefx;
 
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     /* deal with NULL prefix */
     if (NULL == prefix) {
         if (0 > asprintf(&prefx, " ")) {
@@ -734,6 +771,8 @@ pmix_status_t pmix12_bfrop_print_value(char **output, char *prefix, pmix_value_t
     char *prefx;
     int rc;
 
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     /* deal with NULL prefix */
     if (NULL == prefix) {
         if (0 > asprintf(&prefx, " ")) {
@@ -843,6 +882,8 @@ pmix_status_t pmix12_bfrop_print_info(char **output, char *prefix, pmix_info_t *
     char *tmp;
     int rc;
 
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     pmix12_bfrop_print_value(&tmp, NULL, &src->value, PMIX_VALUE);
     rc = asprintf(output, "%sKEY: %s %s", prefix, src->key,
                   (NULL == tmp) ? "PMIX_VALUE: NULL" : tmp);
@@ -861,6 +902,8 @@ pmix_status_t pmix12_bfrop_print_pdata(char **output, char *prefix, pmix_pdata_t
     char *tmp1, *tmp2;
     int rc;
 
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     pmix12_bfrop_print_proc(&tmp1, NULL, &src->proc, PMIX_PROC);
     pmix12_bfrop_print_value(&tmp2, NULL, &src->value, PMIX_VALUE);
     rc = asprintf(output, "%s  %s  KEY: %s %s", prefix, tmp1, src->key,
@@ -880,12 +923,16 @@ pmix_status_t pmix12_bfrop_print_pdata(char **output, char *prefix, pmix_pdata_t
 pmix_status_t pmix12_bfrop_print_buf(char **output, char *prefix, pmix_buffer_t *src,
                                      pmix_data_type_t type)
 {
+    PMIX_HIDE_UNUSED_PARAMS(output, prefix, src, type);
+
     return PMIX_SUCCESS;
 }
 
 pmix_status_t pmix12_bfrop_print_app(char **output, char *prefix, pmix_app_t *src,
                                      pmix_data_type_t type)
 {
+    PMIX_HIDE_UNUSED_PARAMS(output, prefix, src, type);
+
     return PMIX_SUCCESS;
 }
 
@@ -894,6 +941,8 @@ pmix_status_t pmix12_bfrop_print_proc(char **output, char *prefix, pmix_proc_t *
 {
     char *prefx;
 
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     /* deal with NULL prefix */
     if (NULL == prefix) {
         if (0 > asprintf(&prefx, " ")) {
@@ -912,6 +961,8 @@ pmix_status_t pmix12_bfrop_print_proc(char **output, char *prefix, pmix_proc_t *
 pmix_status_t pmix12_bfrop_print_kval(char **output, char *prefix, pmix_kval_t *src,
                                       pmix_data_type_t type)
 {
+    PMIX_HIDE_UNUSED_PARAMS(output, prefix, src, type);
+
     return PMIX_SUCCESS;
 }
 
@@ -922,6 +973,8 @@ pmix_status_t pmix12_bfrop_print_array(char **output, char *prefix, pmix_info_ar
     char *tmp, *tmp2, *tmp3, *pfx;
     pmix_info_t *s1;
 
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     if (0 > asprintf(&tmp, "%sARRAY SIZE: %ld", prefix, (long) src->size)) {
         return PMIX_ERR_NOMEM;
     }
@@ -949,6 +1002,8 @@ pmix_status_t pmix12_bfrop_print_array(char **output, char *prefix, pmix_info_ar
 pmix_status_t pmix12_bfrop_print_modex(char **output, char *prefix, pmix_modex_data_t *src,
                                        pmix_data_type_t type)
 {
+    PMIX_HIDE_UNUSED_PARAMS(output, prefix, src, type);
+
     return PMIX_SUCCESS;
 }
 
@@ -957,6 +1012,8 @@ pmix_status_t pmix12_bfrop_print_persist(char **output, char *prefix, pmix_persi
 {
     char *prefx;
 
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     /* deal with NULL prefix */
     if (NULL == prefix) {
         if (0 > asprintf(&prefx, " ")) {
@@ -992,6 +1049,8 @@ pmix_status_t pmix12_bfrop_print_bo(char **output, char *prefix, pmix_byte_objec
 {
     char *prefx;
 
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     /* deal with NULL prefix */
     if (NULL == prefix) {
         if (0 > asprintf(&prefx, " ")) {
@@ -1025,63 +1084,85 @@ pmix_status_t pmix12_bfrop_print_bo(char **output, char *prefix, pmix_byte_objec
 pmix_status_t pmix12_bfrop_print_scope(char **output, char *prefix, pmix_scope_t *src,
                                        pmix_data_type_t type)
 {
+    PMIX_HIDE_UNUSED_PARAMS(output, prefix, src, type);
+
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
 pmix_status_t pmix12_bfrop_print_status(char **output, char *prefix, pmix_status_t *src,
                                         pmix_data_type_t type)
 {
+    PMIX_HIDE_UNUSED_PARAMS(output, prefix, src, type);
+
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
 pmix_status_t pmix12_bfrop_print_ptr(char **output, char *prefix, void *src, pmix_data_type_t type)
 {
+    PMIX_HIDE_UNUSED_PARAMS(output, prefix, src, type);
+
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
 pmix_status_t pmix12_bfrop_print_cmd(char **output, char *prefix, void *src, pmix_data_type_t type)
 {
+    PMIX_HIDE_UNUSED_PARAMS(output, prefix, src, type);
+
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
 pmix_status_t pmix12_bfrop_print_info_directives(char **output, char *prefix, void *src,
                                                  pmix_data_type_t type)
 {
+    PMIX_HIDE_UNUSED_PARAMS(output, prefix, src, type);
+
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
 pmix_status_t pmix12_bfrop_print_datatype(char **output, char *prefix, pmix_data_type_t *src,
                                           pmix_data_type_t type)
 {
+    PMIX_HIDE_UNUSED_PARAMS(output, prefix, src, type);
+
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
 pmix_status_t pmix12_bfrop_print_proc_state(char **output, char *prefix, pmix_data_type_t *src,
                                             pmix_data_type_t type)
 {
+    PMIX_HIDE_UNUSED_PARAMS(output, prefix, src, type);
+
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
 pmix_status_t pmix12_bfrop_print_darray(char **output, char *prefix, pmix_data_array_t *src,
                                         pmix_data_type_t type)
 {
+    PMIX_HIDE_UNUSED_PARAMS(output, prefix, src, type);
+
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
 pmix_status_t pmix12_bfrop_print_proc_info(char **output, char *prefix, pmix_proc_info_t *src,
                                            pmix_data_type_t type)
 {
+    PMIX_HIDE_UNUSED_PARAMS(output, prefix, src, type);
+
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
 pmix_status_t pmix12_bfrop_print_query(char **output, char *prefix, pmix_query_t *src,
                                        pmix_data_type_t type)
 {
+    PMIX_HIDE_UNUSED_PARAMS(output, prefix, src, type);
+
     return PMIX_ERR_NOT_SUPPORTED;
 }
 
 pmix_status_t pmix12_bfrop_print_rank(char **output, char *prefix, pmix_rank_t *src,
                                       pmix_data_type_t type)
 {
+    PMIX_HIDE_UNUSED_PARAMS(output, prefix, src, type);
+
     return PMIX_ERR_NOT_SUPPORTED;
 }
