@@ -258,6 +258,8 @@ pmix_value_cmp_t pmix20_bfrop_value_cmp(pmix_value_t *p, pmix_value_t *p1)
  */
 pmix_status_t pmix20_bfrop_copy_string(char **dest, char *src, pmix_data_type_t type)
 {
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     if (NULL == src) { /* got zero-length string/NULL pointer - store NULL */
         *dest = NULL;
     } else {
@@ -910,7 +912,9 @@ pmix_status_t pmix20_bfrop_copy_value(pmix_value_t **dest, pmix_value_t *src, pm
 {
     pmix_value_t *p;
 
-    /* create the new object */
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
+   /* create the new object */
     *dest = (pmix_value_t *) malloc(sizeof(pmix_value_t));
     if (NULL == *dest) {
         return PMIX_ERR_OUT_OF_RESOURCE;
@@ -925,6 +929,8 @@ pmix_status_t pmix20_bfrop_copy_value(pmix_value_t **dest, pmix_value_t *src, pm
 
 pmix_status_t pmix20_bfrop_copy_info(pmix_info_t **dest, pmix_info_t *src, pmix_data_type_t type)
 {
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     *dest = (pmix_info_t *) malloc(sizeof(pmix_info_t));
     pmix_strncpy((*dest)->key, src->key, PMIX_MAX_KEYLEN);
     (*dest)->flags = src->flags;
@@ -933,6 +939,8 @@ pmix_status_t pmix20_bfrop_copy_info(pmix_info_t **dest, pmix_info_t *src, pmix_
 
 pmix_status_t pmix20_bfrop_copy_buf(pmix_buffer_t **dest, pmix_buffer_t *src, pmix_data_type_t type)
 {
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     *dest = PMIX_NEW(pmix_buffer_t);
     pmix20_bfrop_copy_payload(*dest, src);
     return PMIX_SUCCESS;
@@ -942,6 +950,8 @@ pmix_status_t pmix20_bfrop_copy_app(pmix_app_t **dest, pmix_app_t *src, pmix_dat
 {
     size_t j;
 
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     *dest = (pmix_app_t *) malloc(sizeof(pmix_app_t));
     (*dest)->cmd = strdup(src->cmd);
     (*dest)->argv = pmix_argv_copy(src->argv);
@@ -963,6 +973,8 @@ pmix_status_t pmix20_bfrop_copy_kval(pmix_kval_t **dest, pmix_kval_t *src, pmix_
 {
     pmix_kval_t *p;
 
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     /* create the new object */
     *dest = PMIX_NEW(pmix_kval_t);
     if (NULL == *dest) {
@@ -978,6 +990,8 @@ pmix_status_t pmix20_bfrop_copy_kval(pmix_kval_t **dest, pmix_kval_t *src, pmix_
 
 pmix_status_t pmix20_bfrop_copy_proc(pmix_proc_t **dest, pmix_proc_t *src, pmix_data_type_t type)
 {
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     *dest = (pmix_proc_t *) malloc(sizeof(pmix_proc_t));
     if (NULL == *dest) {
         return PMIX_ERR_OUT_OF_RESOURCE;
@@ -990,6 +1004,8 @@ pmix_status_t pmix20_bfrop_copy_proc(pmix_proc_t **dest, pmix_proc_t *src, pmix_
 pmix_status_t pmix20_bfrop_copy_modex(pmix_modex_data_t **dest, pmix_modex_data_t *src,
                                       pmix_data_type_t type)
 {
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     *dest = (pmix_modex_data_t *) malloc(sizeof(pmix_modex_data_t));
     if (NULL == *dest) {
         return PMIX_ERR_OUT_OF_RESOURCE;
@@ -1010,6 +1026,8 @@ pmix_status_t pmix20_bfrop_copy_modex(pmix_modex_data_t **dest, pmix_modex_data_
 pmix_status_t pmix20_bfrop_copy_persist(pmix_persistence_t **dest, pmix_persistence_t *src,
                                         pmix_data_type_t type)
 {
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     *dest = (pmix_persistence_t *) malloc(sizeof(pmix_persistence_t));
     if (NULL == *dest) {
         return PMIX_ERR_OUT_OF_RESOURCE;
@@ -1021,6 +1039,8 @@ pmix_status_t pmix20_bfrop_copy_persist(pmix_persistence_t **dest, pmix_persiste
 pmix_status_t pmix20_bfrop_copy_bo(pmix_byte_object_t **dest, pmix_byte_object_t *src,
                                    pmix_data_type_t type)
 {
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     *dest = (pmix_byte_object_t *) malloc(sizeof(pmix_byte_object_t));
     if (NULL == *dest) {
         return PMIX_ERR_OUT_OF_RESOURCE;
@@ -1033,6 +1053,8 @@ pmix_status_t pmix20_bfrop_copy_bo(pmix_byte_object_t **dest, pmix_byte_object_t
 
 pmix_status_t pmix20_bfrop_copy_pdata(pmix_pdata_t **dest, pmix_pdata_t *src, pmix_data_type_t type)
 {
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     *dest = (pmix_pdata_t *) malloc(sizeof(pmix_pdata_t));
     pmix_strncpy((*dest)->proc.nspace, src->proc.nspace, PMIX_MAX_NSLEN);
     (*dest)->proc.rank = src->proc.rank;
@@ -1043,6 +1065,8 @@ pmix_status_t pmix20_bfrop_copy_pdata(pmix_pdata_t **dest, pmix_pdata_t *src, pm
 pmix_status_t pmix20_bfrop_copy_pinfo(pmix_proc_info_t **dest, pmix_proc_info_t *src,
                                       pmix_data_type_t type)
 {
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     *dest = (pmix_proc_info_t *) malloc(sizeof(pmix_proc_info_t));
     pmix_strncpy((*dest)->proc.nspace, src->proc.nspace, PMIX_MAX_NSLEN);
     (*dest)->proc.rank = src->proc.rank;
@@ -1079,6 +1103,8 @@ pmix_status_t pmix20_bfrop_copy_darray(pmix_data_array_t **dest, pmix_data_array
     pmix_proc_info_t *pi, *si;
     pmix_query_t *pq, *sq;
 
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     p = (pmix_data_array_t *) calloc(1, sizeof(pmix_data_array_t));
     if (NULL == p) {
         return PMIX_ERR_NOMEM;
@@ -1293,7 +1319,7 @@ pmix_status_t pmix20_bfrop_copy_darray(pmix_data_array_t **dest, pmix_data_array
         p1 = (pmix_info_t *) p->array;
         s1 = (pmix_info_t *) src->array;
         for (n = 0; n < src->size; n++) {
-            PMIX_INFO_LOAD(&p1[n], s1[n].key, &s1[n].value.data.flag, s1[n].value.type);
+            PMIX_INFO_XFER(&p1[n], &s1[n]);
         }
         break;
     case PMIX_PDATA:
@@ -1305,7 +1331,7 @@ pmix_status_t pmix20_bfrop_copy_darray(pmix_data_array_t **dest, pmix_data_array
         pd = (pmix_pdata_t *) p->array;
         sd = (pmix_pdata_t *) src->array;
         for (n = 0; n < src->size; n++) {
-            PMIX_PDATA_LOAD(&pd[n], &sd[n].proc, sd[n].key, &sd[n].value.data, sd[n].value.type);
+            PMIX_PDATA_XFER(&pd[n], &sd[n]);
         }
         break;
     case PMIX_BUFFER:
@@ -1511,6 +1537,8 @@ pmix_status_t pmix20_bfrop_copy_query(pmix_query_t **dest, pmix_query_t *src, pm
 {
     pmix_status_t rc;
 
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     *dest = (pmix_query_t *) malloc(sizeof(pmix_query_t));
     if (NULL != src->keys) {
         (*dest)->keys = pmix_argv_copy(src->keys);
@@ -1532,6 +1560,8 @@ pmix_status_t pmix20_bfrop_copy_array(pmix_info_array_t **dest, pmix_info_array_
 {
     pmix_info_t *d1, *s1;
 
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     *dest = (pmix_info_array_t *) malloc(sizeof(pmix_info_array_t));
     (*dest)->size = src->size;
     (*dest)->array = (pmix_info_t *) malloc(src->size * sizeof(pmix_info_t));
