@@ -101,6 +101,9 @@ pmix_gds_base_module_t pmix_hash_module = {.name = "hash",
 
 static pmix_status_t hash_init(pmix_info_t info[], size_t ninfo)
 {
+
+    PMIX_HIDE_UNUSED_PARAMS(info, ninfo);
+
     return PMIX_SUCCESS;
 }
 
@@ -632,7 +635,7 @@ static pmix_status_t register_info(pmix_peer_t *peer, pmix_namespace_t *ns, pmix
                             "FETCHING PROC INFO FOR RANK %s", PMIX_RANK_PRINT(rank));
         val = NULL;
         rc = pmix_hash_fetch(ht, rank, NULL, &val);
-        if (PMIX_SUCCESS != rc && PMIX_ERR_PROC_ENTRY_NOT_FOUND != rc) {
+        if (PMIX_SUCCESS != rc && PMIX_ERR_NOT_FOUND != rc) {
             PMIX_ERROR_LOG(rc);
             if (NULL != val) {
                 PMIX_VALUE_RELEASE(val);
@@ -998,10 +1001,9 @@ static pmix_status_t hash_store_job_info(const char *nspace, pmix_buffer_t *buf)
                     kptr->value->data.bo.size = len;
                 }
             }
-            pmix_output_verbose(
-                2, pmix_gds_base_framework.framework_output,
-                "[%s:%u] pmix:gds:hash store job info storing key %s for WILDCARD rank",
-                pmix_globals.myid.nspace, pmix_globals.myid.rank, kptr->key);
+            pmix_output_verbose(2, pmix_gds_base_framework.framework_output,
+                                "[%s:%u] pmix:gds:hash store job info storing key %s for WILDCARD rank",
+                                pmix_globals.myid.nspace, pmix_globals.myid.rank, kptr->key);
             if (PMIX_SUCCESS != (rc = pmix_hash_store(ht, PMIX_RANK_WILDCARD, kptr))) {
                 PMIX_ERROR_LOG(rc);
                 PMIX_RELEASE(kptr);
@@ -1237,6 +1239,8 @@ static pmix_status_t _hash_store_modex(pmix_gds_base_ctx_t ctx, pmix_proc_t *pro
                         "[%s:%d] gds:hash:store_modex for nspace %s", pmix_globals.myid.nspace,
                         pmix_globals.myid.rank, proc->nspace);
 
+    PMIX_HIDE_UNUSED_PARAMS(ctx);
+
     /* find the hash table for this nspace */
     trk = pmix_gds_hash_get_tracker(proc->nspace, true);
     if (NULL == trk) {
@@ -1285,6 +1289,9 @@ static pmix_status_t _hash_store_modex(pmix_gds_base_ctx_t ctx, pmix_proc_t *pro
 
 static pmix_status_t setup_fork(const pmix_proc_t *proc, char ***env)
 {
+
+    PMIX_HIDE_UNUSED_PARAMS(proc, env);
+
     /* we don't need to add anything */
     return PMIX_SUCCESS;
 }
@@ -1292,6 +1299,9 @@ static pmix_status_t setup_fork(const pmix_proc_t *proc, char ***env)
 static pmix_status_t nspace_add(const char *nspace, uint32_t nlocalprocs, pmix_info_t info[],
                                 size_t ninfo)
 {
+
+    PMIX_HIDE_UNUSED_PARAMS(nspace, nlocalprocs, info, ninfo);
+
     /* we don't need to do anything here */
     return PMIX_SUCCESS;
 }
@@ -1300,6 +1310,7 @@ static pmix_status_t nspace_del(const char *nspace)
 {
     pmix_job_t *t;
 
+
     /* find the hash table for this nspace */
     PMIX_LIST_FOREACH (t, &mca_gds_hash_component.myjobs, pmix_job_t) {
         if (0 == strcmp(nspace, t->ns)) {
