@@ -19,7 +19,9 @@
  *                         and Technology (RIST).  All rights reserved.
  * Copyright (c) 2017      Mellanox Technologies Ltd. All rights reserved.
  * Copyright (c) 2017      IBM Corporation. All rights reserved.
- * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
+ * Copyright (c) 2021-2022 Nanook Consulting  All rights reserved.
+ * Copyright (c) 2022      Amazon.com, Inc. or its affiliates.
+ *                         All Rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -158,7 +160,7 @@ void pmix_pfexec_base_spawn_proc(int sd, short args, void *cbdata)
 
     /* create a namespace for the new job */
     memset(tmp, 0, 2048);
-    (void) snprintf(tmp, 2047, "%s:%lu", pmix_globals.myid.nspace,
+    (void) pmix_snprintf(tmp, 2047, "%s:%lu", pmix_globals.myid.nspace,
                     (unsigned long) pmix_pfexec_globals.nextid);
     PMIX_LOAD_NSPACE(nspace, tmp);
     ++pmix_pfexec_globals.nextid;
@@ -194,18 +196,10 @@ void pmix_pfexec_base_spawn_proc(int sd, short args, void *cbdata)
      * launch their procs */
     for (m = 0; m < fcd->napps; m++) {
         app = (pmix_app_t *) &fcd->apps[m];
-
         /* merge our launch environment into the app's */
-        for (i = 0; NULL != environ[i]; i++) {
-            ptr = strchr(environ[i], '=');
-            if (NULL == ptr) {
-                continue;
-            }
-            *ptr = '\0';
-            ++ptr;
-            pmix_setenv(environ[i], ptr, false, &app->env); // do not overwrite a given value
-            --ptr;
-            *ptr = '=';
+        rc = pmix_environ_merge_inplace(&app->env, environ);
+        if (PMIX_SUCCESS != rc) {
+            goto complete;
         }
 
         /* process any job-info */
@@ -303,7 +297,7 @@ void pmix_pfexec_base_spawn_proc(int sd, short args, void *cbdata)
 
             /* pass the rank */
             memset(tmp, 0, 2048);
-            (void) snprintf(tmp, 2047, "%u", child->proc.rank);
+            (void) pmix_snprintf(tmp, 2047, "%u", child->proc.rank);
             pmix_setenv("PMIX_RANK", tmp, true, &env);
             pmix_setenv("PMIX_SERVER_RANK", tmp, true, &env);
 
@@ -323,8 +317,14 @@ void pmix_pfexec_base_spawn_proc(int sd, short args, void *cbdata)
 
             /* setup a keepalive pipe unless "nohup" was given */
             if (!nohup) {
-                pipe(child->keepalive);
-                snprintf(sock, 10, "%d", child->keepalive[1]);
+                rc = pipe(child->keepalive);
+                if (0 != rc) {
+                    PMIX_ERROR_LOG(PMIX_ERR_SYS_OTHER);
+                    pmix_list_remove_item(&pmix_pfexec_globals.children, &child->super);
+                    PMIX_RELEASE(child);
+                    goto complete;
+                }
+                pmix_snprintf(sock, 10, "%d", child->keepalive[1]);
                 pmix_setenv("PMIX_KEEPALIVE_PIPE", sock, true, &env);
             }
 
@@ -379,14 +379,6 @@ void pmix_pfexec_base_kill_proc(int sd, short args, void *cbdata)
         return;
     }
 
-#if 0
-    /* if we opened the stdin IOF channel, be sure
-     * we close it */
-    if (NULL != orte_iof.close) {
-        orte_iof.close(&child->name, ORTE_IOF_STDIN);
-    }
-#endif
-
     /* remove the child from the list so waitpid callback won't
      * find it as this induces unmanageable race
      * conditions when we are deliberately killing the process
@@ -421,11 +413,6 @@ void pmix_pfexec_base_kill_proc(int sd, short args, void *cbdata)
     PMIX_RELEASE(child);
     PMIX_WAKEUP_THREAD(scd->lock);
 
-#if 0
-    /* ensure the child's session directory is cleaned up */
-    orte_session_dir_finalize(&child->name);
-#endif
-
     return;
 }
 
@@ -461,8 +448,6 @@ static pmix_status_t setup_prefork(pmix_pfexec_child_t *child)
 {
     int ret = -1;
     pmix_pfexec_base_io_conf_t *opts = &child->opts;
-    pmix_proc_t *targets = NULL;
-    pmix_info_t *directives = NULL;
 
     fflush(stdout);
 
@@ -494,25 +479,14 @@ static pmix_status_t setup_prefork(pmix_pfexec_child_t *child)
         return PMIX_ERR_SYS_OTHER;
     }
 
-#if 0
-    /* connect stdin endpoint */
-    if (opts->connect_stdin) {
-        /* and connect the pty to stdin */
-        ret = orte_iof.pull(name, ORTE_IOF_STDIN, opts->p_stdin[1]);
-        if(ORTE_SUCCESS != ret) {
-            ORTE_ERROR_LOG(ret);
-            return ret;
-        }
-    }
-#endif
     /* connect read ends to IOF */
-    PMIX_IOF_READ_EVENT(&child->stdoutev, targets, 0, directives, 0, opts->p_stdout[0],
-                        pmix_iof_read_local_handler, false);
+    PMIX_IOF_READ_EVENT_LOCAL(&child->stdoutev, opts->p_stdout[0],
+                              pmix_iof_read_local_handler, false);
     PMIX_LOAD_PROCID(&child->stdoutev->name, child->proc.nspace, child->proc.rank);
     child->stdoutev->childproc = (void *) child;
     child->stdoutev->channel = PMIX_FWD_STDOUT_CHANNEL;
-    PMIX_IOF_READ_EVENT(&child->stderrev, targets, 0, directives, 0, opts->p_stderr[0],
-                        pmix_iof_read_local_handler, false);
+    PMIX_IOF_READ_EVENT_LOCAL(&child->stderrev, opts->p_stderr[0],
+                              pmix_iof_read_local_handler, false);
     PMIX_LOAD_PROCID(&child->stderrev->name, child->proc.nspace, child->proc.rank);
     child->stderrev->childproc = (void *) child;
     child->stderrev->channel = PMIX_FWD_STDERR_CHANNEL;
@@ -673,6 +647,13 @@ static pmix_status_t register_nspace(char *nspace, pmix_pfexec_fork_caddy_t *fcd
         return rc;
     }
 
+    /* mark us as the parent */
+    PMIX_INFO_LIST_ADD(rc, jinfo, PMIX_PARENT_ID, &pmix_globals.myid, PMIX_PROC);
+    if (PMIX_SUCCESS != rc) {
+        PMIX_INFO_LIST_RELEASE(jinfo);
+        return rc;
+    }
+
     /* node size */
     PMIX_INFO_LIST_ADD(rc, jinfo, PMIX_NODE_SIZE, &nprocs, PMIX_UINT32);
     if (PMIX_SUCCESS != rc) {
