@@ -24,7 +24,7 @@ static void pinstalldirs_env_init(pmix_info_t info[], size_t ninfo);
 pmix_pinstalldirs_base_component_t mca_pinstalldirs_env_component = {
     /* First, the mca_component_t struct containing meta information
        about the component itself */
-    {
+    .component = {
         PMIX_PINSTALLDIRS_BASE_VERSION_1_0_0,
 
         /* Component name and version */
@@ -33,12 +33,30 @@ pmix_pinstalldirs_base_component_t mca_pinstalldirs_env_component = {
         PMIX_MINOR_VERSION,
         PMIX_RELEASE_VERSION,
     },
-    {/* This component is checkpointable */
-     PMIX_MCA_BASE_METADATA_PARAM_CHECKPOINT},
+    .component_data = {/* This component is checkpointable */
+        PMIX_MCA_BASE_METADATA_PARAM_CHECKPOINT,
+        .reserved = {0}
+    },
 
     /* Next the pmix_pinstall_dirs_t install_dirs_data information */
-    {
-        NULL,
+    .install_dirs_data = {
+        .prefix = NULL,
+        .exec_prefix = NULL,
+        .bindir = NULL,
+        .sbindir = NULL,
+        .libexecdir = NULL,
+        .datarootdir = NULL,
+        .datadir = NULL,
+        .sysconfdir = NULL,
+        .sharedstatedir = NULL,
+        .localstatedir = NULL,
+        .libdir = NULL,
+        .includedir = NULL,
+        .infodir = NULL,
+        .mandir = NULL,
+        .pmixdatadir = NULL,
+        .pmixlibdir = NULL,
+        .pmixincludedir = NULL
     },
     .init = pinstalldirs_env_init};
 
