@@ -33,7 +33,8 @@ pmix_plog_base_component_t mca_plog_default_component = {
     },
     .data = {
         /* The component is checkpoint ready */
-        PMIX_MCA_BASE_METADATA_PARAM_CHECKPOINT
+        PMIX_MCA_BASE_METADATA_PARAM_CHECKPOINT,
+        .reserved = {0}
     },
 };
 
