@@ -1,6 +1,7 @@
 /*
- * Copyright (c) 2018      Intel, Inc. All rights reserved.
+ * Copyright (c) 2018-2020 Intel, Inc.  All rights reserved.
  *
+ * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -11,8 +12,7 @@
 #ifndef PMIX_PNET_OPA_H
 #define PMIX_PNET_OPA_H
 
-#include <src/include/pmix_config.h>
-
+#include "src/include/pmix_config.h"
 
 #include "src/mca/pnet/pnet.h"
 
@@ -22,8 +22,12 @@ typedef struct {
     pmix_pnet_base_component_t super;
     char *static_ports;
     char *default_request;
+    char *incparms;
+    char *excparms;
     char **include;
     char **exclude;
+    int nverts;
+    uint16_t **costmatrix;
 } pmix_pnet_tcp_component_t;
 
 /* the component must be visible data for the linker to find it */
