@@ -1,6 +1,7 @@
 /*
- * Copyright (c) 2015-2016 Intel, Inc.  All rights reserved.
+ * Copyright (c) 2015-2020 Intel, Inc.  All rights reserved.
  *
+ * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -11,8 +12,7 @@
 #ifndef PMIX_NATIVE_H
 #define PMIX_NATIVE_H
 
-#include <src/include/pmix_config.h>
-
+#include "src/include/pmix_config.h"
 
 #include "src/mca/psec/psec.h"
 
