@@ -70,6 +70,9 @@ void pmix_ptl_base_connection_handler(int sd, short args, void *cbdata)
     /* acquire the object */
     PMIX_ACQUIRE_OBJECT(pnd);
 
+    // must use sd, args to avoid -Werror
+    PMIX_HIDE_UNUSED_PARAMS(sd, args);
+
     pmix_output_verbose(8, pmix_ptl_base_framework.framework_output,
                         "ptl:base:connection_handler: new connection: %d", pnd->sd);
 
@@ -240,6 +243,7 @@ void pmix_ptl_base_connection_handler(int sd, short args, void *cbdata)
         if (NULL != blob) {
             free(blob);
         }
+        free(msg);
         return;
     }
 
@@ -420,6 +424,9 @@ void pmix_ptl_base_connection_handler(int sd, short args, void *cbdata)
 
     /* check the cached events and update the client */
     _check_cached_events(peer);
+    if (NULL != blob) {
+        free(blob);
+    }
 
     return;
 
@@ -431,6 +438,9 @@ error:
     if (NULL != msg) {
         free(msg);
     }
+    if (NULL != blob) {
+        free(blob);
+    }
     if (NULL != peer) {
         pmix_pointer_array_set_item(&pmix_server_globals.clients, peer->index, NULL);
         PMIX_RELEASE(peer);
@@ -456,6 +466,9 @@ static void process_cbfunc(int sd, short args, void *cbdata)
 
     /* acquire the object */
     PMIX_ACQUIRE_OBJECT(cd);
+    // must use sd, args to avoid -Werror
+    PMIX_HIDE_UNUSED_PARAMS(sd, args);
+
     /* shortcuts */
     peer = (pmix_peer_t *) pnd->peer;
     nptr = peer->nptr;
