@@ -194,11 +194,6 @@ pmix_status_t pmix_ptl_base_check_directives(pmix_info_t *info, size_t ninfo)
                 free(pmix_ptl_base.uri);
             }
             pmix_ptl_base.uri = strdup(info[n].value.data.string);
-        } else if (PMIX_CHECK_KEY(&info[n], PMIX_TCP_REPORT_URI)) {
-            if (NULL != pmix_ptl_base.report_uri) {
-                free(pmix_ptl_base.report_uri);
-            }
-            pmix_ptl_base.report_uri = strdup(info[n].value.data.string);
         } else if (PMIX_CHECK_KEY(&info[n], PMIX_SERVER_TMPDIR)) {
             if (NULL != pmix_ptl_base.session_tmpdir) {
                 free(pmix_ptl_base.session_tmpdir);
@@ -226,6 +221,8 @@ pmix_status_t pmix_ptl_base_check_directives(pmix_info_t *info, size_t ninfo)
 
 pmix_status_t pmix_ptl_base_setup_fork(const pmix_proc_t *proc, char ***env)
 {
+    PMIX_HIDE_UNUSED_PARAMS(proc);
+
     pmix_setenv("PMIX_SERVER_TMPDIR", pmix_ptl_base.session_tmpdir, true, env);
     pmix_setenv("PMIX_SYSTEM_TMPDIR", pmix_ptl_base.system_tmpdir, true, env);
 
@@ -285,7 +282,7 @@ pmix_status_t pmix_ptl_base_parse_uri_file(char *filename, pmix_list_t *connecti
      * be configured to support tool connections, or this
      * user isn't authorized to access it - or it may just
      * not exist yet! Check for existence */
-    /* coverity[toctou] */
+    /* coverity[TOCTOU] */
     if (0 != access(filename, R_OK)) {
         if (ENOENT == errno) {
             /* the file does not exist, so give it
@@ -312,7 +309,7 @@ pmix_status_t pmix_ptl_base_parse_uri_file(char *filename, pmix_list_t *connecti
                 }
                 PMIX_WAIT_THREAD(&lock);
                 PMIX_DESTRUCT_LOCK(&lock);
-                /* coverity[toctou] */
+                /* coverity[TOCTOU] */
                 if (0 == access(filename, R_OK)) {
                     goto process;
                 }
@@ -390,6 +387,7 @@ pmix_status_t pmix_ptl_base_df_search(char *dirname, char *prefix, pmix_info_t i
     struct stat buf;
     DIR *cur_dirp;
     struct dirent *dir_entry;
+    pmix_status_t rc;
 
     if (NULL == (cur_dirp = opendir(dirname))) {
         return PMIX_ERR_NOT_FOUND;
@@ -405,7 +403,7 @@ pmix_status_t pmix_ptl_base_df_search(char *dirname, char *prefix, pmix_info_t i
             continue;
         }
         newdir = pmix_os_path(false, dirname, dir_entry->d_name, NULL);
-        /* coverity[toctou] */
+        /* coverity[TOCTOU] */
         if (-1 == stat(newdir, &buf)) {
             free(newdir);
             continue;
@@ -423,7 +421,12 @@ pmix_status_t pmix_ptl_base_df_search(char *dirname, char *prefix, pmix_info_t i
             /* try to read this file */
             pmix_output_verbose(2, pmix_ptl_base_framework.framework_output,
                                 "pmix:tool: reading file %s", newdir);
-            pmix_ptl_base_parse_uri_file(newdir, connections);
+            rc = pmix_ptl_base_parse_uri_file(newdir, connections);
+            if (PMIX_SUCCESS != rc) {
+                free(newdir);
+                closedir(cur_dirp);
+                return rc;
+            }
         }
         free(newdir);
     }
@@ -669,7 +672,7 @@ void pmix_ptl_base_complete_connection(pmix_peer_t *peer, char *nspace, pmix_ran
     /* store the URI for subsequent lookups */
     PMIX_KVAL_NEW(urikv, PMIX_SERVER_URI);
     urikv->value->type = PMIX_STRING;
-    asprintf(&urikv->value->data.string, "%s.%u;%s", nspace, rank, suri);
+    pmix_asprintf(&urikv->value->data.string, "%s.%u;%s", nspace, rank, suri);
     PMIX_GDS_STORE_KV(rc, pmix_globals.mypeer, &pmix_globals.myid, PMIX_INTERNAL, urikv);
     if (PMIX_SUCCESS != rc) {
         PMIX_ERROR_LOG(rc);
@@ -832,7 +835,9 @@ pmix_status_t pmix_ptl_base_construct_message(pmix_peer_t *peer, char **msgout,
     if (NULL == (msg = (char *) malloc(sdsize))) {
         PMIX_BYTE_OBJECT_DESTRUCT(&cred);
         free(sec);
-        PMIX_DESTRUCT(&buf);
+        if (NULL != iptr) {
+            PMIX_DESTRUCT(&buf);
+        }
         return PMIX_ERR_OUT_OF_RESOURCE;
     }
     memset(msg, 0, sdsize);
@@ -899,7 +904,9 @@ pmix_status_t pmix_ptl_base_construct_message(pmix_peer_t *peer, char **msgout,
 
     default:
         /* we don't know what they are! */
-        PMIX_DESTRUCT(&buf);
+        if (NULL != iptr) {
+            PMIX_DESTRUCT(&buf);
+        }
         free(msg);
         return PMIX_ERR_NOT_SUPPORTED;
     }
@@ -949,6 +956,7 @@ pmix_status_t pmix_ptl_base_set_timeout(pmix_peer_t *peer, struct timeval *save,
 
 void pmix_ptl_base_setup_socket(pmix_peer_t *peer)
 {
+    PMIX_HIDE_UNUSED_PARAMS(peer);
 #if defined(TCP_NODELAY)
     int optval;
     optval = 1;
@@ -1078,7 +1086,7 @@ static void check_server(char *filename, pmix_list_t *servers)
      * be configured to support tool connections, or this
      * user isn't authorized to access it - or it may just
      * not exist yet! Check for existence */
-    /* coverity[toctou] */
+    /* coverity[TOCTOU] */
     if (0 == access(filename, R_OK)) {
         goto process;
     } else {
@@ -1107,7 +1115,7 @@ static void check_server(char *filename, pmix_list_t *servers)
                 }
                 PMIX_WAIT_THREAD(&lock);
                 PMIX_DESTRUCT_LOCK(&lock);
-                /* coverity[toctou] */
+                /* coverity[TOCTOU] */
                 if (0 == access(filename, R_OK)) {
                     goto process;
                 }
@@ -1156,6 +1164,7 @@ process:
         if (NULL != nspace) {
             free(nspace);
         }
+        free(srvr);
         return;
     }
 
@@ -1298,7 +1307,7 @@ static void query_servers(char *dirname, pmix_list_t *servers)
             continue;
         }
         newdir = pmix_os_path(false, dname, dir_entry->d_name, NULL);
-        /* coverity[toctou] */
+        /* coverity[TOCTOU] */
         if (-1 == stat(newdir, &buf)) {
             free(newdir);
             continue;
@@ -1341,6 +1350,8 @@ void pmix_ptl_base_query_servers(int sd, short args, void *cbdata)
     pmix_infolist_t *iptr;
     pmix_status_t rc;
 
+    PMIX_HIDE_UNUSED_PARAMS(sd, args);
+
     PMIX_CONSTRUCT(&servers, pmix_list_t);
 
     query_servers(NULL, &servers);
@@ -1367,6 +1378,8 @@ void pmix_ptl_base_query_servers(int sd, short args, void *cbdata)
 static void timeout(int sd, short args, void *cbdata)
 {
     pmix_lock_t *lock = (pmix_lock_t *) cbdata;
+    PMIX_HIDE_UNUSED_PARAMS(sd, args);
+
     PMIX_WAKEUP_THREAD(lock);
 }
 
@@ -1390,39 +1403,41 @@ static char *pmix_getline(FILE *fp)
  * (a.b.c.d/e), resolve them to an interface name (Currently only
  * supporting IPv4).  If unresolvable, warn and remove.
  */
-char **pmix_ptl_base_split_and_resolve(char **orig_str, char *name)
+char **pmix_ptl_base_split_and_resolve(const char *orig_str,
+                                       const char *name)
 {
-    int i, ret, save, if_index;
-    char **argv, *str, *tmp;
+    int i, ret, if_index;
+    char **argv, **interfaces, *str;
     char if_name[PMIX_IF_NAMESIZE];
     struct sockaddr_storage argv_inaddr, if_inaddr;
     uint32_t argv_prefix;
+    bool found;
 
     /* Sanity check */
-    if (NULL == orig_str || NULL == *orig_str) {
+    if (NULL == orig_str) {
         return NULL;
     }
 
-    argv = pmix_argv_split(*orig_str, ',');
-    if (NULL == argv) {
-        return NULL;
-    }
-    for (save = i = 0; NULL != argv[i]; ++i) {
+    argv = pmix_argv_split(orig_str, ',');
+    interfaces = NULL;
+    for (i = 0; NULL != argv[i]; ++i) {
         if (isalpha(argv[i][0])) {
-            argv[save++] = argv[i];
+            /* This is an interface name. If not already in the interfaces array, add it */
+            pmix_argv_append_unique_nosize(&interfaces, argv[i]);
+            pmix_output_verbose(20,
+                                pmix_ptl_base_framework.framework_output,
+                                "ptl:tool: Using interface: %s ", argv[i]);
             continue;
         }
 
         /* Found a subnet notation.  Convert it to an IP
            address/netmask.  Get the prefix first. */
         argv_prefix = 0;
-        tmp = strdup(argv[i]);
         str = strchr(argv[i], '/');
         if (NULL == str) {
-            pmix_show_help("help-ptl-base.txt", "invalid if_inexclude", true, name, tmp,
+            pmix_show_help("help-ptl-base.txt", "invalid if_inexclude", true,
+                           name, pmix_globals.hostname, argv[i],
                            "Invalid specification (missing \"/\")");
-            free(argv[i]);
-            free(tmp);
             continue;
         }
         *str = '\0';
@@ -1431,48 +1446,46 @@ char **pmix_ptl_base_split_and_resolve(char **orig_str, char *name)
         /* Now convert the IPv4 address */
         ((struct sockaddr *) &argv_inaddr)->sa_family = AF_INET;
         ret = inet_pton(AF_INET, argv[i], &((struct sockaddr_in *) &argv_inaddr)->sin_addr);
-        free(argv[i]);
+        *str = '/';
 
         if (1 != ret) {
-            pmix_show_help("help-ptl-base.txt", "invalid if_inexclude", true, name, tmp,
+            pmix_show_help("help-ptl-base.txt", "invalid if_inexclude", true,
+                           name, pmix_globals.hostname, argv[i],
                            "Invalid specification (inet_pton() failed)");
-            free(tmp);
             continue;
         }
         pmix_output_verbose(20, pmix_ptl_base_framework.framework_output,
-                            "ptl:tool: Searching for %s address+prefix: %s / %u", name,
+                            "ptl:base: Searching for %s address+prefix: %s / %u", name,
                             pmix_net_get_hostname((struct sockaddr *) &argv_inaddr), argv_prefix);
 
         /* Go through all interfaces and see if we can find a match */
+        found = false;
         for (if_index = pmix_ifbegin(); if_index >= 0; if_index = pmix_ifnext(if_index)) {
-            pmix_ifindextoaddr(if_index, (struct sockaddr *) &if_inaddr, sizeof(if_inaddr));
-            if (pmix_net_samenetwork((struct sockaddr *) &argv_inaddr,
-                                     (struct sockaddr *) &if_inaddr, argv_prefix)) {
-                break;
+            pmix_ifindextoaddr(if_index,
+                               (struct sockaddr*) &if_inaddr,
+                               sizeof(if_inaddr));
+            if (pmix_net_samenetwork(&argv_inaddr, &if_inaddr, argv_prefix)) {
+                /* We found a match. If it's not already in the interfaces array,
+                   add it. If it's already in the array, treat it as a match */
+                found = true;
+                pmix_ifindextoname(if_index, if_name, sizeof(if_name));
+                pmix_argv_append_unique_nosize(&interfaces, if_name);
+                pmix_output_verbose(20,
+                                    pmix_ptl_base_framework.framework_output,
+                                    "ptl:base: Found match: %s (%s)",
+                                    pmix_net_get_hostname((struct sockaddr*) &if_inaddr),
+                                    if_name);
             }
-        }
-        /* If we didn't find a match, keep trying */
-        if (if_index < 0) {
-            pmix_show_help("help-ptl-base.txt", "invalid if_inexclude", true, name, tmp,
-                           "Did not find interface matching this subnet");
-            free(tmp);
-            continue;
-        }
 
-        /* We found a match; get the name and replace it in the
-           argv */
-        pmix_ifindextoname(if_index, if_name, sizeof(if_name));
-        pmix_output_verbose(20, pmix_ptl_base_framework.framework_output,
-                            "ptl:tool: Found match: %s (%s)",
-                            pmix_net_get_hostname((struct sockaddr *) &if_inaddr), if_name);
-        argv[save++] = strdup(if_name);
-        free(tmp);
+        }
+        /* If we didn't find a match, report it but keep trying */
+        if (!found) {
+            pmix_show_help("help-ptl-base.txt", "invalid if_inexclude", true,
+                           name, pmix_globals.hostname, argv[i],
+                           "Did not find interface matching this subnet");
+        }
     }
 
-    /* The list may have been compressed if there were invalid
-       entries, so ensure we end it with a NULL entry */
-    argv[save] = NULL;
-    free(*orig_str);
-    *orig_str = pmix_argv_join(argv, ',');
-    return argv;
+    pmix_argv_free(argv);
+    return interfaces;
 }
