@@ -45,7 +45,7 @@
 #endif
 #include <ctype.h>
 #include <sys/stat.h>
-#include PMIX_EVENT_HEADER
+#include <event.h>
 #include <pthread.h>
 
 #include "src/class/pmix_list.h"
@@ -299,7 +299,7 @@ pmix_status_t pmix_ptl_base_setup_listener(void)
 {
     int flags = 0;
     pmix_listener_t *lt;
-    int i, rc = 0, saveindex = -1;
+    int i, rc = 0, saveindex = -1, savelpbk = -1;
     char **interfaces = NULL;
     bool including = false;
     char name[32];
@@ -324,10 +324,10 @@ pmix_status_t pmix_ptl_base_setup_listener(void)
      * subnet+mask
      */
     if (NULL != pmix_ptl_base.if_include) {
-        interfaces = pmix_ptl_base_split_and_resolve(&pmix_ptl_base.if_include, "include");
+        interfaces = pmix_ptl_base_split_and_resolve(pmix_ptl_base.if_include, "include");
         including = true;
     } else if (NULL != pmix_ptl_base.if_exclude) {
-        interfaces = pmix_ptl_base_split_and_resolve(&pmix_ptl_base.if_exclude, "exclude");
+        interfaces = pmix_ptl_base_split_and_resolve(pmix_ptl_base.if_exclude, "exclude");
         including = false;
     }
 
@@ -407,13 +407,11 @@ pmix_status_t pmix_ptl_base_setup_listener(void)
         /* if this is the loopback device and they didn't enable
          * remote connections, then we are done */
         if (pmix_ifisloopback(i)) {
-            if (pmix_ptl_base.remote_connections) {
-                /* ignore loopback */
-                continue;
-            } else {
-                pmix_output_verbose(5, pmix_ptl_base_framework.framework_output,
-                                    "ptl:tool:init loopback interface %s selected", name);
-                saveindex = i;
+            pmix_output_verbose(5, pmix_ptl_base_framework.framework_output,
+                                "ptl:tool:init loopback interface %s found", name);
+            savelpbk = i;
+            if (!pmix_ptl_base.remote_connections) {
+                saveindex = savelpbk;
                 break;
             }
         } else {
@@ -429,14 +427,21 @@ pmix_status_t pmix_ptl_base_setup_listener(void)
         pmix_argv_free(interfaces);
     }
 
-    /* if we didn't find anything, then we cannot operate */
+    /* if we didn't find anything, that could be a problem */
     if (saveindex < 0) {
-        return PMIX_ERR_NOT_AVAILABLE;
+        /* if ONLY a loopback is available, then even if they
+         * enabled remote connections, it's the best we can do */
+        if (savelpbk < 0) {
+            /* if NOTHING is available, then neither are we */
+            return PMIX_ERR_NOT_AVAILABLE;
+        } else {
+            saveindex = savelpbk;
+        }
     }
 
     /* save the connection */
     if (PMIX_SUCCESS
-        != pmix_ifindextoaddr(saveindex, (struct sockaddr *) &pmix_ptl_base.connection,
+        != pmix_ifindextoaddr(saveindex, (struct sockaddr *) pmix_ptl_base.connection,
                               sizeof(struct sockaddr))) {
         pmix_output(0, "ptl:base: problems getting address for kernel index %i\n",
                     pmix_ifindextokindex(saveindex));
@@ -444,15 +449,15 @@ pmix_status_t pmix_ptl_base_setup_listener(void)
     }
 
     /* set the port */
-    if (AF_INET == pmix_ptl_base.connection.ss_family) {
-        ((struct sockaddr_in *) &pmix_ptl_base.connection)->sin_port = htons(
+    if (AF_INET == pmix_ptl_base.connection->ss_family) {
+        ((struct sockaddr_in *) pmix_ptl_base.connection)->sin_port = htons(
             pmix_ptl_base.ipv4_port);
         addrlen = sizeof(struct sockaddr_in);
         if (0 != pmix_ptl_base.ipv4_port) {
             flags = 1;
         }
-    } else if (AF_INET6 == pmix_ptl_base.connection.ss_family) {
-        ((struct sockaddr_in6 *) &pmix_ptl_base.connection)->sin6_port = htons(
+    } else if (AF_INET6 == pmix_ptl_base.connection->ss_family) {
+        ((struct sockaddr_in6 *) pmix_ptl_base.connection)->sin6_port = htons(
             pmix_ptl_base.ipv6_port);
         addrlen = sizeof(struct sockaddr_in6);
         if (0 != pmix_ptl_base.ipv6_port) {
@@ -471,7 +476,7 @@ pmix_status_t pmix_ptl_base_setup_listener(void)
     lt->cbfunc = pmix_ptl_base_connection_handler;
 
     /* create a listen socket for incoming connection attempts */
-    lt->socket = socket(pmix_ptl_base.connection.ss_family, SOCK_STREAM, 0);
+    lt->socket = socket(pmix_ptl_base.connection->ss_family, SOCK_STREAM, 0);
     if (lt->socket < 0) {
         printf("%s:%d socket() failed\n", __FILE__, __LINE__);
         goto sockerror;
@@ -493,14 +498,14 @@ pmix_status_t pmix_ptl_base_setup_listener(void)
         goto sockerror;
     }
 
-    if (bind(lt->socket, (struct sockaddr *) &pmix_ptl_base.connection, addrlen) < 0) {
+    if (bind(lt->socket, (struct sockaddr *) pmix_ptl_base.connection, addrlen) < 0) {
         printf("[%u] %s:%d bind() failed for socket %d storage size %u: %s\n", (unsigned) getpid(),
                __FILE__, __LINE__, lt->socket, (unsigned) addrlen, strerror(errno));
         goto sockerror;
     }
 
     /* resolve assigned port */
-    if (getsockname(lt->socket, (struct sockaddr *) &pmix_ptl_base.connection, &addrlen) < 0) {
+    if (getsockname(lt->socket, (struct sockaddr *) pmix_ptl_base.connection, &addrlen) < 0) {
         pmix_output(0, "ptl:tool:create_listen: getsockname(): %s (%d)",
                     strerror(pmix_socket_errno), pmix_socket_errno);
         goto sockerror;
@@ -523,15 +528,15 @@ pmix_status_t pmix_ptl_base_setup_listener(void)
         goto sockerror;
     }
 
-    if (AF_INET == pmix_ptl_base.connection.ss_family) {
+    if (AF_INET == pmix_ptl_base.connection->ss_family) {
         prefix = "tcp4://";
-        myport = ntohs(((struct sockaddr_in *) &pmix_ptl_base.connection)->sin_port);
-        inet_ntop(AF_INET, &((struct sockaddr_in *) &pmix_ptl_base.connection)->sin_addr,
+        myport = ntohs(((struct sockaddr_in *) pmix_ptl_base.connection)->sin_port);
+        inet_ntop(AF_INET, &((struct sockaddr_in *) pmix_ptl_base.connection)->sin_addr,
                   myconnhost, PMIX_MAXHOSTNAMELEN - 1);
-    } else if (AF_INET6 == pmix_ptl_base.connection.ss_family) {
+    } else if (AF_INET6 == pmix_ptl_base.connection->ss_family) {
         prefix = "tcp6://";
-        myport = ntohs(((struct sockaddr_in6 *) &pmix_ptl_base.connection)->sin6_port);
-        inet_ntop(AF_INET6, &((struct sockaddr_in6 *) &pmix_ptl_base.connection)->sin6_addr,
+        myport = ntohs(((struct sockaddr_in6 *) pmix_ptl_base.connection)->sin6_port);
+        inet_ntop(AF_INET6, &((struct sockaddr_in6 *) pmix_ptl_base.connection)->sin6_addr,
                   myconnhost, PMIX_MAXHOSTNAMELEN - 1);
     } else {
         goto sockerror;
@@ -597,7 +602,7 @@ pmix_status_t pmix_ptl_base_setup_listener(void)
          * server */
         if (PMIX_PEER_IS_TOOL(pmix_globals.mypeer)) {
             struct stat buf;
-            /* coverity[toctou] */
+            /* coverity[TOCTOU] */
             if (0 == stat(pmix_ptl_base.rendezvous_filename, &buf)) {
                 goto nextstep;
             }
