@@ -38,7 +38,6 @@
 #include "src/mca/pcompress/base/base.h"
 #include "src/mca/pif/base/base.h"
 #include "src/mca/pinstalldirs/base/base.h"
-#include "src/mca/ploc/base/base.h"
 #include "src/mca/plog/base/base.h"
 #include "src/mca/pnet/base/base.h"
 #include "src/mca/preg/base/base.h"
@@ -48,7 +47,7 @@
 #include "src/util/keyval_parse.h"
 #include "src/util/output.h"
 #include "src/util/show_help.h"
-#include PMIX_EVENT_HEADER
+#include <event.h>
 
 #include "src/runtime/pmix_progress_threads.h"
 #include "src/runtime/pmix_rte.h"
@@ -73,9 +72,6 @@ void pmix_rte_finalize(void)
     /* release the attribute support trackers */
     pmix_release_registered_attrs();
 
-    /* close ploc */
-    (void) pmix_mca_base_framework_close(&pmix_ploc_base_framework);
-
     /* close plog */
     (void) pmix_mca_base_framework_close(&pmix_plog_base_framework);
 
