@@ -63,6 +63,7 @@ typedef struct {
     pmix_app_t *apps;
     size_t napps;
     pmix_iof_channel_t channels;
+    pmix_iof_flags_t flags;
     pmix_byte_object_t *bo;
     size_t nbo;
     /* timestamp receipt of the notification so we
@@ -183,13 +184,13 @@ typedef struct {
     pmix_list_t collectives;      // list of active pmix_server_trkr_t
     pmix_list_t remote_pnd; // list of pmix_dmdx_remote_t awaiting arrival of data fror servicing
                             // remote req's
-    pmix_list_t
-        local_reqs;     // list of pmix_dmdx_local_t awaiting arrival of data from local neighbours
+    pmix_list_t local_reqs;     // list of pmix_dmdx_local_t awaiting arrival of data from local neighbours
     pmix_list_t gdata;  // cache of data given to me for passing to all clients
     char **genvars;     // argv array of envars given to me for passing to all clients
     pmix_list_t events; // list of pmix_regevents_info_t registered events
     pmix_list_t groups; // list of pmix_group_t group memberships
     pmix_list_t iof;    // IO to be forwarded to clients
+    pmix_list_t iof_residuals;  // leftover bytes waiting for newline
     pmix_list_t psets;  // list of known psets and memberships
     size_t max_iof_cache; // max number of IOF messages to cache
     bool tool_connections_allowed;
@@ -353,6 +354,10 @@ PMIX_EXPORT pmix_status_t pmix_server_fabric_get_device_index(pmix_server_caddy_
                                                               pmix_buffer_t *buf,
                                                               pmix_info_cbfunc_t cbfunc);
 
+PMIX_EXPORT pmix_status_t pmix_server_device_dists(pmix_server_caddy_t *cd,
+                                                   pmix_buffer_t *buf,
+                                                   pmix_device_dist_cbfunc_t cbfunc);
+
 PMIX_EXPORT extern pmix_server_module_t pmix_host_server;
 PMIX_EXPORT extern pmix_server_globals_t pmix_server_globals;
 
