@@ -2,6 +2,7 @@
 /*
  * Copyright (c) 2020      Intel, Inc.  All rights reserved.
  *
+ * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  */
 
@@ -9,13 +10,10 @@
 #define PMIX_TOOL_OPS_H
 
 #include "src/include/pmix_config.h"
-#include "src/include/types.h"
 #include "src/include/pmix_globals.h"
+#include "src/include/types.h"
 
-
-PMIX_EXPORT pmix_status_t pmix_tool_relay_op(pmix_cmd_t cmd,
-                                             pmix_peer_t *peer,
-                                             pmix_buffer_t *bfr,
+PMIX_EXPORT pmix_status_t pmix_tool_relay_op(pmix_cmd_t cmd, pmix_peer_t *peer, pmix_buffer_t *bfr,
                                              uint32_t tag);
 
 #endif // PMIX_TOOL_OPS_H
