@@ -110,6 +110,9 @@ static void notification_fn(size_t evhdlr_registration_id, pmix_status_t status,
                             pmix_info_t results[], size_t nresults,
                             pmix_event_notification_cbfunc_fn_t cbfunc, void *cbdata)
 {
+    PMIX_HIDE_UNUSED_PARAMS(evhdlr_registration_id, status,
+                            source, info, ninfo, results, nresults);
+
     /* this example doesn't do anything with default events */
     if (NULL != cbfunc) {
         cbfunc(PMIX_EVENT_ACTION_COMPLETE, NULL, 0, NULL, NULL, cbdata);
@@ -156,32 +159,49 @@ typedef struct {
     bool hostfns;
 } pmix_pquery_globals_t;
 
-pmix_pquery_globals_t pmix_pquery_globals = {0};
+pmix_pquery_globals_t pmix_pquery_globals = {
+    .help = false,
+    .verbose = false,
+    .pid = 0,
+    .nspace = NULL,
+    .uri = NULL,
+    .sysfirst = false,
+    .system = false,
+    .client = NULL,
+    .server = NULL,
+    .tool = NULL,
+    .host = NULL,
+    .clientfns = false,
+    .serverfns = false,
+    .toolfns = false,
+    .hostfns = false
+};
 
 pmix_cmd_line_init_t cmd_line_opts[]
     = {{NULL, 'h', NULL, "help", 0, &pmix_pquery_globals.help, PMIX_CMD_LINE_TYPE_BOOL,
-        "This help message"},
+        "This help message", PMIX_CMD_LINE_OTYPE_GENERAL},
 
        {NULL, 'v', NULL, "verbose", 0, &pmix_pquery_globals.verbose, PMIX_CMD_LINE_TYPE_BOOL,
-        "Be Verbose"},
+        "Be Verbose", PMIX_CMD_LINE_OTYPE_GENERAL},
 
        {NULL, 'p', NULL, "pid", 1, &pmix_pquery_globals.pid, PMIX_CMD_LINE_TYPE_INT,
-        "Specify server pid to connect to"},
+        "Specify server pid to connect to", PMIX_CMD_LINE_OTYPE_GENERAL},
 
        {NULL, 'n', NULL, "nspace", 1, &pmix_pquery_globals.nspace, PMIX_CMD_LINE_TYPE_STRING,
-        "Specify server nspace to connect to"},
+        "Specify server nspace to connect to", PMIX_CMD_LINE_OTYPE_GENERAL},
 
        {NULL, '\0', NULL, "uri", 1, &pmix_pquery_globals.uri, PMIX_CMD_LINE_TYPE_STRING,
-        "Specify URI of server to connect to"},
+        "Specify URI of server to connect to", PMIX_CMD_LINE_OTYPE_GENERAL},
 
        {NULL, '\0', NULL, "system-server-first", 0, &pmix_pquery_globals.sysfirst,
-        PMIX_CMD_LINE_TYPE_BOOL, "Look for the system server first"},
+        PMIX_CMD_LINE_TYPE_BOOL, "Look for the system server first", PMIX_CMD_LINE_OTYPE_GENERAL},
 
        {NULL, '\0', NULL, "system-server", 0, &pmix_pquery_globals.system, PMIX_CMD_LINE_TYPE_BOOL,
-        "Specifically connect to the system server"},
+        "Specifically connect to the system server", PMIX_CMD_LINE_OTYPE_GENERAL},
 
        /* End of list */
-       {NULL, '\0', NULL, NULL, 0, NULL, PMIX_CMD_LINE_TYPE_NULL, NULL}};
+       {NULL, '\0', NULL, NULL, 0, NULL, PMIX_CMD_LINE_TYPE_NULL, NULL, PMIX_CMD_LINE_OTYPE_GENERAL}
+    };
 
 int main(int argc, char **argv)
 {
@@ -190,7 +210,12 @@ int main(int argc, char **argv)
     mylock_t mylock;
     pmix_cmd_line_t cmd_line;
     size_t n, m, k, nqueries, ninfo, ndarray;
-    myquery_data_t mq = {{0}};
+    myquery_data_t mq = {
+        .lock = PMIX_LOCK_STATIC_INIT,
+        .status = 0,
+        .info = NULL,
+        .ninfo = 0
+    };
     int count;
     char **qkeys = NULL;
     const char *attr;
