@@ -9,7 +9,8 @@
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
- * Copyright (c) 2016-2017 Intel, Inc. All rights reserved.
+ * Copyright (c) 2016-2020 Intel, Inc.  All rights reserved.
+ * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -22,7 +23,7 @@
 #ifndef PMIX_UTIL_KEYVAL_PARSE_H
 #define PMIX_UTIL_KEYVAL_PARSE_H
 
-#include <src/include/pmix_config.h>
+#include "src/include/pmix_config.h"
 
 BEGIN_C_DECLS
 
@@ -46,8 +47,7 @@ typedef void (*pmix_keyval_parse_fn_t)(const char *key, const char *value);
  * called exactly once.  In a multithreaded context, calls to
  * pmix_util_keyval_parse() will serialize multiple calls.
  */
-PMIX_EXPORT int pmix_util_keyval_parse(const char *filename,
-                                       pmix_keyval_parse_fn_t callback);
+PMIX_EXPORT int pmix_util_keyval_parse(const char *filename, pmix_keyval_parse_fn_t callback);
 
 PMIX_EXPORT int pmix_util_keyval_parse_init(void);
 
