@@ -249,29 +249,27 @@ int16_t pmix_ifaddrtokindex(const char *if_addr)
     for (r = res; r != NULL; r = r->ai_next) {
         PMIX_LIST_FOREACH (intf, &pmix_if_list, pmix_pif_t) {
             if (AF_INET == r->ai_family && AF_INET == intf->af_family) {
-                struct sockaddr_in ipv4, intv4;
-                memset(&ipv4, 0, sizeof(struct sockaddr_in));
+                struct sockaddr_storage ipv4, intv4;
                 len = (r->ai_addrlen < sizeof(struct sockaddr_in)) ? r->ai_addrlen
                                                                    : sizeof(struct sockaddr_in);
+                memset(&ipv4, 0, sizeof(struct sockaddr_storage));
                 memcpy(&ipv4, r->ai_addr, len);
-                memset(&intv4, 0, sizeof(struct sockaddr_in));
+                memset(&intv4, 0, sizeof(struct sockaddr_storage));
                 memcpy(&intv4, &intf->if_addr, sizeof(struct sockaddr_in));
-                if (pmix_net_samenetwork((struct sockaddr *) &ipv4, (struct sockaddr *) &intv4,
-                                         intf->if_mask)) {
+                if (pmix_net_samenetwork(&ipv4, &intv4, intf->if_mask)) {
                     if_kernel_index = intf->if_kernel_index;
                     freeaddrinfo(res);
                     return if_kernel_index;
                 }
             } else if (AF_INET6 == r->ai_family && AF_INET6 == intf->af_family) {
-                struct sockaddr_in6 ipv6, intv6;
-                memset(&ipv6, 0, sizeof(struct sockaddr));
+                struct sockaddr_storage ipv6, intv6;
                 len = (r->ai_addrlen < sizeof(struct sockaddr_in6)) ? r->ai_addrlen
                                                                     : sizeof(struct sockaddr_in6);
+                memset(&ipv6, 0, sizeof(struct sockaddr_storage));
                 memcpy(&ipv6, r->ai_addr, len);
-                memset(&intv6, 0, sizeof(struct sockaddr));
+                memset(&intv6, 0, sizeof(struct sockaddr_storage));
                 memcpy(&intv6, &intf->if_addr, sizeof(struct sockaddr_in6));
-                if (pmix_net_samenetwork((struct sockaddr *) &intv6, (struct sockaddr *) &ipv6,
-                                         intf->if_mask)) {
+                if (pmix_net_samenetwork(&intv6, &ipv6, intf->if_mask)) {
                     if_kernel_index = intf->if_kernel_index;
                     freeaddrinfo(res);
                     return if_kernel_index;
