@@ -65,6 +65,9 @@ pmix_status_t connected(const pmix_proc_t *proc, void *server_object, pmix_op_cb
     if (NULL != cbfunc) {
         cbfunc(PMIX_SUCCESS, cbdata);
     }
+
+    PMIX_HIDE_UNUSED_PARAMS(proc, server_object);
+
     return PMIX_SUCCESS;
 }
 
@@ -73,6 +76,8 @@ pmix_status_t finalized(const pmix_proc_t *proc, void *server_object, pmix_op_cb
 {
     cli_info_t *cli = NULL;
     int i;
+    PMIX_HIDE_UNUSED_PARAMS(server_object);
+
     for (i = 0; i < cli_info_cnt; i++) {
         if ((proc->rank == cli_info[i].rank) && (0 == strcmp(proc->nspace, cli_info[i].ns))) {
             cli = &cli_info[i];
@@ -107,6 +112,7 @@ pmix_status_t abort_fn(const pmix_proc_t *proc, void *server_object, int status,
     if (NULL != cbfunc) {
         cbfunc(PMIX_SUCCESS, cbdata);
     }
+    PMIX_HIDE_UNUSED_PARAMS(proc, server_object, procs, nprocs);
     TEST_VERBOSE(("Abort is called with status = %d, msg = %s", status, msg));
     test_abort = true;
     return PMIX_SUCCESS;
@@ -116,6 +122,7 @@ pmix_status_t fencenb_fn(const pmix_proc_t procs[], size_t nprocs, const pmix_in
                          size_t ninfo, char *data, size_t ndata, pmix_modex_cbfunc_t cbfunc,
                          void *cbdata)
 {
+    PMIX_HIDE_UNUSED_PARAMS(procs, nprocs, info, ninfo);
     TEST_VERBOSE(("Getting data for %s:%d", procs[0].nspace, procs[0].rank));
 
     if ((pmix_list_get_size(server_list) == 1) && (my_server_id == 0)) {
@@ -189,6 +196,9 @@ pmix_status_t lookup_fn(const pmix_proc_t *proc, char **keys, const pmix_info_t
     pmix_status_t rc = PMIX_SUCCESS;
     pmix_pdata_t *pdata;
     pmix_test_info_t *tinfo;
+
+    PMIX_HIDE_UNUSED_PARAMS(proc, info, ninfo);
+
     if (NULL == pmix_test_published_list) {
         return PMIX_ERR_NOT_FOUND;
     }
@@ -198,10 +208,10 @@ pmix_status_t lookup_fn(const pmix_proc_t *proc, char **keys, const pmix_info_t
     for (i = 0; i < ndata; i++) {
         PMIX_LIST_FOREACH (tinfo, pmix_test_published_list, pmix_test_info_t) {
             if (0 == strcmp(tinfo->data.key, keys[i])) {
-                (void) strncpy(pdata[i].proc.nspace, tinfo->namespace_published, PMIX_MAX_NSLEN);
+                pmix_strncpy(pdata[i].proc.nspace, tinfo->namespace_published, PMIX_MAX_NSLEN);
                 pdata[i].proc.rank = tinfo->rank_published;
                 memset(pdata[i].key, 0, PMIX_MAX_KEYLEN + 1);
-                (void) strncpy(pdata[i].key, keys[i], PMIX_MAX_KEYLEN);
+                pmix_strncpy(pdata[i].key, keys[i], PMIX_MAX_KEYLEN);
                 pmix_value_xfer(&pdata[i].value, &tinfo->data.value);
                 ret++;
                 break;
@@ -225,6 +235,9 @@ pmix_status_t unpublish_fn(const pmix_proc_t *proc, char **keys, const pmix_info
 {
     size_t i;
     pmix_test_info_t *iptr, *next;
+
+    PMIX_HIDE_UNUSED_PARAMS(proc, info);
+
     if (NULL == pmix_test_published_list) {
         return PMIX_ERR_NOT_FOUND;
     }
@@ -272,6 +285,8 @@ static void release_cb(pmix_status_t status, void *cbdata)
 {
     pthread_t thread;
 
+    PMIX_HIDE_UNUSED_PARAMS(status);
+
     if (0 > pthread_create(&thread, NULL, _release_cb, cbdata)) {
         spawn_wait = false;
         return;
@@ -283,6 +298,8 @@ pmix_status_t spawn_fn(const pmix_proc_t *proc, const pmix_info_t job_info[], si
                        const pmix_app_t apps[], size_t napps, pmix_spawn_cbfunc_t cbfunc,
                        void *cbdata)
 {
+    PMIX_HIDE_UNUSED_PARAMS(proc, job_info, ninfo, apps);
+
     release_cbdata *cb = malloc(sizeof(release_cbdata));
     pmix_nspace_t foobar;
 
@@ -300,6 +317,8 @@ static int numconnect = 0;
 pmix_status_t connect_fn(const pmix_proc_t procs[], size_t nprocs, const pmix_info_t info[],
                          size_t ninfo, pmix_op_cbfunc_t cbfunc, void *cbdata)
 {
+    PMIX_HIDE_UNUSED_PARAMS(procs, nprocs, info, ninfo);
+
     if (NULL != cbfunc) {
         cbfunc(PMIX_SUCCESS, cbdata);
     }
@@ -310,6 +329,8 @@ pmix_status_t connect_fn(const pmix_proc_t procs[], size_t nprocs, const pmix_in
 pmix_status_t disconnect_fn(const pmix_proc_t procs[], size_t nprocs, const pmix_info_t info[],
                             size_t ninfo, pmix_op_cbfunc_t cbfunc, void *cbdata)
 {
+    PMIX_HIDE_UNUSED_PARAMS(procs, nprocs, info, ninfo);
+
     if (NULL != cbfunc) {
         cbfunc(PMIX_SUCCESS, cbdata);
     }
@@ -319,6 +340,8 @@ pmix_status_t disconnect_fn(const pmix_proc_t procs[], size_t nprocs, const pmix
 pmix_status_t regevents_fn(pmix_status_t *codes, size_t ncodes, const pmix_info_t info[],
                            size_t ninfo, pmix_op_cbfunc_t cbfunc, void *cbdata)
 {
+    PMIX_HIDE_UNUSED_PARAMS(ncodes, codes, info, ninfo);
+
     TEST_VERBOSE((" pmix host server regevents_fn called "));
     if (NULL != cbfunc) {
         cbfunc(PMIX_SUCCESS, cbdata);
@@ -329,6 +352,8 @@ pmix_status_t regevents_fn(pmix_status_t *codes, size_t ncodes, const pmix_info_
 pmix_status_t deregevents_fn(pmix_status_t *codes, size_t ncodes, pmix_op_cbfunc_t cbfunc,
                              void *cbdata)
 {
+    PMIX_HIDE_UNUSED_PARAMS(ncodes, codes);
+
     TEST_VERBOSE((" pmix host server deregevents_fn called "));
     if (NULL != cbfunc) {
         cbfunc(PMIX_SUCCESS, cbdata);
