@@ -33,6 +33,7 @@
 #include <unistd.h>
 
 #include "src/class/pmix_object.h"
+#include "src/include/pmix_globals.h"
 #include "src/util/output.h"
 #include "src/util/printf.h"
 
@@ -50,6 +51,7 @@ static uint32_t getcount = 0;
 static void opcbfunc(pmix_status_t status, void *cbdata)
 {
     bool *active = (bool *) cbdata;
+    PMIX_HIDE_UNUSED_PARAMS(status);
 
     pmix_output(0, "%s:%d completed fence_nb", myproc.nspace, myproc.rank);
     *active = false;
@@ -110,7 +112,8 @@ int main(int argc, char **argv)
     bool dofence = true;
     bool local, all_local;
     char **peers;
-    pmix_rank_t *locals;
+    pmix_rank_t *locals = NULL;
+    PMIX_HIDE_UNUSED_PARAMS(argc, argv);
 
     if (NULL != getenv("PMIX_SIMPDMODEX_ASYNC")) {
         dofence = false;
@@ -125,7 +128,7 @@ int main(int argc, char **argv)
     pmix_output(0, "Client ns %s rank %d: Running", myproc.nspace, myproc.rank);
 
     /* get our job size */
-    (void) strncpy(proc.nspace, myproc.nspace, PMIX_MAX_NSLEN);
+    pmix_strncpy(proc.nspace, myproc.nspace, PMIX_MAX_NSLEN);
     proc.rank = PMIX_RANK_WILDCARD;
     if (PMIX_SUCCESS != (rc = PMIx_Get(&proc, PMIX_JOB_SIZE, NULL, 0, &val))) {
         pmix_output(0, "Client ns %s rank %d: PMIx_Get job size failed: %s", myproc.nspace,
@@ -181,7 +184,7 @@ int main(int argc, char **argv)
     if (dofence) {
         /* call fence_nb, but don't return any data */
         PMIX_PROC_CONSTRUCT(&proc);
-        (void) strncpy(proc.nspace, myproc.nspace, PMIX_MAX_NSLEN);
+        pmix_strncpy(proc.nspace, myproc.nspace, PMIX_MAX_NSLEN);
         proc.rank = PMIX_RANK_WILDCARD;
         active = true;
         if (PMIX_SUCCESS != (rc = PMIx_Fence_nb(&proc, 1, NULL, 0, opcbfunc, &active))) {
