@@ -279,7 +279,7 @@ typedef struct {
         TEST_VERBOSE(("%s:%d want to get from %s:%d key %s", my_nspace, my_rank, ns, r, _key));   \
         if (blocking) {                                                                           \
             if (PMIX_SUCCESS != (rc = PMIx_Get(&_foobar, _key, NULL, 0, &_val))) {                \
-                if (!((rc == PMIX_ERR_NOT_FOUND || rc == PMIX_ERR_PROC_ENTRY_NOT_FOUND)           \
+                if (!((rc == PMIX_ERR_NOT_FOUND || rc == PMIX_ERR_NOT_FOUND)           \
                       && ok_notfnd)) {                                                            \
                     TEST_ERROR(("%s:%d: PMIx_Get failed: %s from %s:%d, key %s", my_nspace,       \
                                 my_rank, PMIx_Error_string(rc), ns, r, _key));                    \
@@ -309,8 +309,7 @@ typedef struct {
         }                                                                                         \
         if (PMIX_SUCCESS == rc) {                                                                 \
             if (PMIX_SUCCESS != _cbdata.status) {                                                 \
-                if (!((_cbdata.status == PMIX_ERR_NOT_FOUND                                       \
-                       || _cbdata.status == PMIX_ERR_PROC_ENTRY_NOT_FOUND)                        \
+                if (!((_cbdata.status == PMIX_ERR_NOT_FOUND)                                      \
                       && ok_notfnd)) {                                                            \
                     TEST_ERROR(("%s:%d: PMIx_Get_nb failed: %s from %s:%d, key=%s", my_nspace,    \
                                 my_rank, PMIx_Error_string(rc), my_nspace, r, _key));             \
@@ -339,7 +338,7 @@ typedef struct {
             if (data_ex) {                                                                     \
                 bool _value = 1;                                                               \
                 PMIX_INFO_CREATE(_info, 1);                                                    \
-                (void) strncpy(_info->key, PMIX_COLLECT_DATA, PMIX_MAX_KEYLEN);                \
+                pmix_strncpy(_info->key, PMIX_COLLECT_DATA, PMIX_MAX_KEYLEN);                \
                 pmix_value_load(&_info->value, &_value, PMIX_BOOL);                            \
                 _ninfo = 1;                                                                    \
             }                                                                                  \
